/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_6NSQsth5);
  numBytes += sLine_init(&sLine_Owg2YtKz);
  numBytes += sLine_init(&sLine_CrisXiUv);
  numBytes += sLine_init(&sLine_RwU0CIMw);
  numBytes += sLine_init(&sLine_NKOtsfnR);
  numBytes += sBiquad_init(&sBiquad_s_6S0tWAmx);
  numBytes += sLine_init(&sLine_FVJBk0wk);
  numBytes += sLine_init(&sLine_rhOeetHW);
  numBytes += sLine_init(&sLine_tMhboijr);
  numBytes += sLine_init(&sLine_Wnf6PQ95);
  numBytes += sBiquad_init(&sBiquad_s_8t5ybtyo);
  numBytes += sLine_init(&sLine_uiccnkjz);
  numBytes += sLine_init(&sLine_rEfFKhb3);
  numBytes += sLine_init(&sLine_CR715b1u);
  numBytes += sLine_init(&sLine_7AsExIOX);
  numBytes += sLine_init(&sLine_dDmxEGbs);
  numBytes += sBiquad_init(&sBiquad_s_tepSYcim);
  numBytes += sLine_init(&sLine_1wsZQByj);
  numBytes += sLine_init(&sLine_il55jxCz);
  numBytes += sLine_init(&sLine_814at4iS);
  numBytes += sLine_init(&sLine_DhO695Aq);
  numBytes += sLine_init(&sLine_7hO7PyUW);
  numBytes += sBiquad_init(&sBiquad_s_dcUmkjUj);
  numBytes += sLine_init(&sLine_e0ohxC5o);
  numBytes += sLine_init(&sLine_g1Ojihd3);
  numBytes += sLine_init(&sLine_sEv5FaSF);
  numBytes += sLine_init(&sLine_lv5LIyAk);
  numBytes += sBiquad_init(&sBiquad_s_7mqyWKQA);
  numBytes += sLine_init(&sLine_MWHRS08p);
  numBytes += sLine_init(&sLine_V3YKR3P2);
  numBytes += sLine_init(&sLine_35wh2VeU);
  numBytes += sLine_init(&sLine_FygbfStq);
  numBytes += sLine_init(&sLine_vaugzlV4);
  numBytes += sBiquad_init(&sBiquad_s_r8aCAKM1);
  numBytes += sLine_init(&sLine_Rc23rZ59);
  numBytes += sTabread_init(&sTabread_WPcLVBhM, &hTable_eoPEpddH, true);
  numBytes += sLine_init(&sLine_sYD2Uyey);
  numBytes += sLine_init(&sLine_3rxDs3xy);
  numBytes += sTabread_init(&sTabread_1brIOGkA, &hTable_Cqyzl2Nl, true);
  numBytes += sLine_init(&sLine_Q3oZm1lY);
  numBytes += sRPole_init(&sRPole_m7SmKRVT);
  numBytes += sDel1_init(&sDel1_btW8hw9K);
  numBytes += sTabwrite_init(&sTabwrite_CYTQE1B0, &hTable_eoPEpddH);
  numBytes += sRPole_init(&sRPole_4J1uzIXJ);
  numBytes += sDel1_init(&sDel1_eCKLqkvs);
  numBytes += sTabwrite_init(&sTabwrite_rrxit976, &hTable_Cqyzl2Nl);
  numBytes += sLine_init(&sLine_4T3rMgH9);
  numBytes += sLine_init(&sLine_X6SomIef);
  numBytes += sRPole_init(&sRPole_27iG6HUy);
  numBytes += sEnv_init(&sEnv_oPREYVrW, 1024, 512);
  numBytes += sRPole_init(&sRPole_LcHz0YQf);
  numBytes += sLine_init(&sLine_vrvoMgsf);
  numBytes += sLine_init(&sLine_eoUFaBLt);
  numBytes += sRPole_init(&sRPole_EuJw5HbI);
  numBytes += sEnv_init(&sEnv_LhHr4qYi, 1024, 512);
  numBytes += sRPole_init(&sRPole_S5y6GHOC);
  numBytes += sLine_init(&sLine_451ToWYh);
  numBytes += sTabread_init(&sTabread_YhFKF7eX, &hTable_14y3n6lS, true);
  numBytes += sLine_init(&sLine_GZcbPNo3);
  numBytes += sLine_init(&sLine_GH1DHAYX);
  numBytes += sTabread_init(&sTabread_yYfm8epR, &hTable_6v0TUFb4, true);
  numBytes += sLine_init(&sLine_vAkhrvc9);
  numBytes += sRPole_init(&sRPole_VJE2VYNO);
  numBytes += sDel1_init(&sDel1_KkcPph27);
  numBytes += sTabwrite_init(&sTabwrite_X1aicy1o, &hTable_14y3n6lS);
  numBytes += sRPole_init(&sRPole_OKQ1W2eq);
  numBytes += sDel1_init(&sDel1_UALfFmfW);
  numBytes += sTabwrite_init(&sTabwrite_hpQ3UYZp, &hTable_6v0TUFb4);
  numBytes += sLine_init(&sLine_IVwkv12O);
  numBytes += sLine_init(&sLine_fAiGLOpp);
  numBytes += sRPole_init(&sRPole_Z1C7oCjU);
  numBytes += sEnv_init(&sEnv_nE6lbdBw, 1024, 512);
  numBytes += sRPole_init(&sRPole_vEyEF2HB);
  numBytes += sLine_init(&sLine_jM0z6W93);
  numBytes += sLine_init(&sLine_nkGOeCMc);
  numBytes += sRPole_init(&sRPole_8Vw9vUUy);
  numBytes += sEnv_init(&sEnv_7QKfknxM, 1024, 512);
  numBytes += sRPole_init(&sRPole_dGiyTGlx);
  numBytes += sLine_init(&sLine_Kq0aZiNG);
  numBytes += sTabread_init(&sTabread_E62LNqw6, &hTable_bLZK9s7Q, true);
  numBytes += sLine_init(&sLine_hglLjnnF);
  numBytes += sLine_init(&sLine_FnvMwhTf);
  numBytes += sTabread_init(&sTabread_pj97Vfhv, &hTable_wQW2h6MV, true);
  numBytes += sLine_init(&sLine_hvgOBvy7);
  numBytes += sRPole_init(&sRPole_n614MNPC);
  numBytes += sDel1_init(&sDel1_kwFla7Au);
  numBytes += sTabwrite_init(&sTabwrite_xoc7icvo, &hTable_bLZK9s7Q);
  numBytes += sRPole_init(&sRPole_TIuOO6wo);
  numBytes += sDel1_init(&sDel1_wFXJeUTQ);
  numBytes += sTabwrite_init(&sTabwrite_SanbvW7K, &hTable_wQW2h6MV);
  numBytes += sLine_init(&sLine_POOmXL08);
  numBytes += sLine_init(&sLine_2D69JTTP);
  numBytes += sRPole_init(&sRPole_SGpvxC45);
  numBytes += sEnv_init(&sEnv_8NFZ0dcN, 1024, 512);
  numBytes += sRPole_init(&sRPole_ZTRMYumW);
  numBytes += sLine_init(&sLine_CM1mrbNv);
  numBytes += sLine_init(&sLine_9HSftv9E);
  numBytes += sRPole_init(&sRPole_GUhy2XkS);
  numBytes += sEnv_init(&sEnv_zq3ROpKc, 1024, 512);
  numBytes += sRPole_init(&sRPole_7gx86sl6);
  numBytes += cVar_init_f(&cVar_SC554AVX, 0.0f);
  numBytes += cVar_init_f(&cVar_RnxCcW47, 0.0f);
  numBytes += cVar_init_f(&cVar_fnK7XIqC, 0.0f);
  numBytes += cVar_init_f(&cVar_bRDBtdpL, 0.0f);
  numBytes += cSlice_init(&cSlice_qYHmi3YG, 1, -1);
  numBytes += cVar_init_f(&cVar_H7ZuMtp3, 1337.0f);
  numBytes += cVar_init_f(&cVar_AXMVPglc, 0.0f);
  numBytes += cIf_init(&cIf_FQM1UkKA, false);
  numBytes += cIf_init(&cIf_t00FDmjB, false);
  numBytes += cBinop_init(&cBinop_HI48ehm4, 0.0f); // __pow
  numBytes += cIf_init(&cIf_leKdk4Ee, false);
  numBytes += cBinop_init(&cBinop_HmVspfC6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_2335brts, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bEFtJkxN, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_BPDWe5hd, 0.0f);
  numBytes += cIf_init(&cIf_bMtgyKFr, false);
  numBytes += cIf_init(&cIf_CGgt95RA, false);
  numBytes += cBinop_init(&cBinop_JbfVmDMs, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Cw3G3pAD, false);
  numBytes += cBinop_init(&cBinop_70BPZK40, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_H844BK8J, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VAuOjzHd, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_QSA0i7qf, 0.0f);
  numBytes += cIf_init(&cIf_q3uAo5ne, false);
  numBytes += cIf_init(&cIf_QaELfDZw, false);
  numBytes += cBinop_init(&cBinop_EP3nihfM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_kgu3WcZU, false);
  numBytes += cBinop_init(&cBinop_3nAepmZf, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_upjeIQsP, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_aRmbEhYG, -15.0f); // __eq
  numBytes += cIf_init(&cIf_giMiNWsU, false);
  numBytes += cSlice_init(&cSlice_rxPVpsRX, 1, -1);
  numBytes += cVar_init_f(&cVar_541IzmcS, 0.0f);
  numBytes += cSlice_init(&cSlice_f8Pm0LkZ, 1, -1);
  numBytes += cVar_init_f(&cVar_I9sCI1nX, 0.0f);
  numBytes += cSlice_init(&cSlice_FB2Opo51, 1, -1);
  numBytes += cVar_init_f(&cVar_sQCsvcCF, 0.0f);
  numBytes += cSlice_init(&cSlice_nByURFxS, 1, -1);
  numBytes += cVar_init_f(&cVar_m3jLGELn, 0.313f);
  numBytes += cBinop_init(&cBinop_zkeAGwZ7, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_NeC5MsOl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FQAtCmYa, 0.0f);
  numBytes += cVar_init_f(&cVar_zAO2NJyR, 1337.0f);
  numBytes += cVar_init_f(&cVar_tteUS2mF, 0.3f);
  numBytes += cBinop_init(&cBinop_rnh85uyo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VPYErsXg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HuPWP6ov, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x7xKexFP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nC5DHLIu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aFWibs4h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hfhjymdp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GY2AvWfW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_tpUgxlnJ, 0.0f);
  numBytes += cVar_init_f(&cVar_YfmffLRQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_MMjGGbTL, 0.313f);
  numBytes += cBinop_init(&cBinop_bxpROE4D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UZds6qLQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_svzfppeX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_95gWsrk9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jsxZ4jO6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Gst6Hh8V, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_E5JI0cUl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OhoStdq7, 0.0f);
  numBytes += cVar_init_f(&cVar_dRnx8aOy, 1037.0f);
  numBytes += cVar_init_f(&cVar_Ml7FwYMR, 0.4f);
  numBytes += cBinop_init(&cBinop_cxZYBH5W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ByfQrqQw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DJas8FSS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tMJwuuwZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aXl76tzq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1nnMRrWK, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jS5QTFbf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K0NY6jWp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9r1mZhI3, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_12G0qa0T, 1, -1);
  numBytes += cVar_init_f(&cVar_UP364Jyl, 1337.0f);
  numBytes += cVar_init_f(&cVar_qGgWQH7u, 0.0f);
  numBytes += cIf_init(&cIf_tN5EqYgx, false);
  numBytes += cIf_init(&cIf_TyxUX38s, false);
  numBytes += cBinop_init(&cBinop_AZr1OJUd, 0.0f); // __pow
  numBytes += cIf_init(&cIf_POSNXZWP, false);
  numBytes += cBinop_init(&cBinop_bpWXLPOz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_AhpQglRZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_dTF1Ug57, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_fjGqHcH3, 0.0f);
  numBytes += cIf_init(&cIf_Z8h5OheN, false);
  numBytes += cIf_init(&cIf_PfstLl1A, false);
  numBytes += cBinop_init(&cBinop_B7eSUd7x, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0jJQ5LIS, false);
  numBytes += cBinop_init(&cBinop_52nhWNAA, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_RNsDt8IS, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_rqdTp0TX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_AUYb7yyj, 0.0f);
  numBytes += cIf_init(&cIf_WnrwoVkA, false);
  numBytes += cIf_init(&cIf_AUK1w4La, false);
  numBytes += cBinop_init(&cBinop_hIp9lapY, 0.0f); // __pow
  numBytes += cIf_init(&cIf_yYz54qVC, false);
  numBytes += cBinop_init(&cBinop_1avPN1sW, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_h7jpuvpl, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_DG9IvLgC, -15.0f); // __eq
  numBytes += cIf_init(&cIf_cOFFGsTt, false);
  numBytes += cSlice_init(&cSlice_42QxJ8Ew, 1, -1);
  numBytes += cVar_init_f(&cVar_Vmhoq3vm, 0.0f);
  numBytes += cSlice_init(&cSlice_4aztasWQ, 1, -1);
  numBytes += cVar_init_f(&cVar_iTjgMaCJ, 0.0f);
  numBytes += cSlice_init(&cSlice_JbMAanxE, 1, -1);
  numBytes += cVar_init_f(&cVar_owLBvaTK, 0.0f);
  numBytes += cSlice_init(&cSlice_fc5VyEVt, 1, -1);
  numBytes += cVar_init_f(&cVar_urrr3jAw, 0.313f);
  numBytes += cBinop_init(&cBinop_5nbl6Jks, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KAfnrLL0, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Kn9oKE4E, 0.0f);
  numBytes += cVar_init_f(&cVar_lsICW6Ef, 1337.0f);
  numBytes += cVar_init_f(&cVar_8etnW6Wy, 0.3f);
  numBytes += cBinop_init(&cBinop_7xauLtuF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IincbQUd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2y58kjVr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_en0SZbjB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XLC0BHqm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YoDBwqLy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zXlXCKJf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qGfwP9ml, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_6odcXRuH, 0.0f);
  numBytes += cVar_init_f(&cVar_5X7OaLsT, 1337.0f);
  numBytes += cVar_init_f(&cVar_M3wupvgF, 0.313f);
  numBytes += cBinop_init(&cBinop_JIIfIUMj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wXezlk8R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3NU6K6Hj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oxOxfzft, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JdW8iSAJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AGraqjmN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_8vJZ0iHb, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7mHLRRZC, 0.0f);
  numBytes += cVar_init_f(&cVar_Bor8zo2u, 1037.0f);
  numBytes += cVar_init_f(&cVar_nGU6olJ6, 0.4f);
  numBytes += cBinop_init(&cBinop_gSZ7QY7q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IgeBzOyP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2cao4MtG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1Jq28Vw0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C9HykDFU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9vakIZrP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Z9hG7now, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BUwGMNzP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2Yis95YL, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0Dis7dIs, 5705.6f);
  numBytes += cVar_init_f(&cVar_JQan1hwu, 313.3f);
  numBytes += cBinop_init(&cBinop_ix12FAmE, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_NzpIap32, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Wl0R3NdN, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_tK517MUO, 0.0f);
  numBytes += cVar_init_f(&cVar_MM6nexoa, 0.0f);
  numBytes += cVar_init_f(&cVar_N6x23vPK, 0.0f);
  numBytes += cVar_init_f(&cVar_wUcHYjhN, 0.0f);
  numBytes += cVar_init_f(&cVar_Jwo37R3o, 0.0f);
  numBytes += cVar_init_f(&cVar_n0V3NO3C, 0.0f);
  numBytes += cVar_init_f(&cVar_JlY8nh9E, 0.0f);
  numBytes += cVar_init_f(&cVar_KZs3SSrk, 0.0f);
  numBytes += cVar_init_f(&cVar_WmUSbVJj, 0.0f);
  numBytes += cVar_init_f(&cVar_9IfaK98A, 0.0f);
  numBytes += cVar_init_f(&cVar_vEE1Ir0w, 0.0f);
  numBytes += cVar_init_f(&cVar_HgH2LGcN, 0.0f);
  numBytes += cSlice_init(&cSlice_2nlg65Gm, 1, -1);
  numBytes += cVar_init_f(&cVar_Tm1s5vAN, 0.5f);
  numBytes += cSlice_init(&cSlice_ddyBTqBQ, 1, -1);
  numBytes += cVar_init_f(&cVar_xyyOTJXW, 0.2f);
  numBytes += cSlice_init(&cSlice_PhmEj4OY, 1, -1);
  numBytes += cVar_init_f(&cVar_8Z2CYF87, 500.0f);
  numBytes += sVarf_init(&sVarf_FckXArST, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_l4VZk7Pj, 600.0f);
  numBytes += cBinop_init(&cBinop_JGqGF1tB, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Dj0dNoF8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bb4GFQUg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_o9ugZ9rR, 600.0f);
  numBytes += cBinop_init(&cBinop_DPUQj8gJ, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_eCiVjmuq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xPmnxjRP, 4000.0f);
  numBytes += cBinop_init(&cBinop_fnzisqHz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cPtZosMS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ax01LzD8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zXdmqJkK, 4000.0f);
  numBytes += cBinop_init(&cBinop_KHoDMfo0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_JqN53mXS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eJaDQ4kW, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_z3LByDyD, false);
  numBytes += cBinop_init(&cBinop_hO6Sxijo, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_gRKl002F, 20.0f);
  numBytes += cBinop_init(&cBinop_WCvw8qfP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rhe2eoJH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7mHlP2Ya, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UAkGPCfn, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_WSDfejaA, false);
  numBytes += cBinop_init(&cBinop_bJKE6OlN, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_qIkhJdFo, 20.0f);
  numBytes += cBinop_init(&cBinop_B0mQuqhA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_TJN5nFZ1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MzY4EkUR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_98VINtJS, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_DTRBVgXs, 1, -1);
  numBytes += cVar_init_f(&cVar_rI76b9rE, 0.25f);
  numBytes += cDelay_init(this, &cDelay_Db49bACo, 0.0f);
  numBytes += cDelay_init(this, &cDelay_A70xWnOx, 0.0f);
  numBytes += hTable_init(&hTable_eoPEpddH, 256);
  numBytes += cTabhead_init(&cTabhead_cNSuZUQ3, &hTable_eoPEpddH);
  numBytes += cVar_init_s(&cVar_N0tkwQMR, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_qy1Yyw75, 0.0f);
  numBytes += cDelay_init(this, &cDelay_AfFf4PxP, 0.0f);
  numBytes += cBinop_init(&cBinop_5VubsKcw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GwhHp49n, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_5JctRDPT, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_IIgmnERw, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_6YCoTOad, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BSPyrPl5, 0.0f);
  numBytes += hTable_init(&hTable_Cqyzl2Nl, 256);
  numBytes += cTabhead_init(&cTabhead_OtwtNCH8, &hTable_Cqyzl2Nl);
  numBytes += cVar_init_s(&cVar_uJzzydHj, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_fGFATPfC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uIRi5lfe, 0.0f);
  numBytes += cBinop_init(&cBinop_YJfUIxIy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VdheAb2B, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4MHhzpuk, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_PVepO5O2, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_EAQeZJZy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gEBKNC8v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_daCreM4f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SYRDSIpl, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_o6jhHI0x, 1, -1);
  numBytes += cVar_init_f(&cVar_CbfpwLXS, 0.5f);
  numBytes += cSlice_init(&cSlice_JnfU408Q, 1, -1);
  numBytes += cVar_init_f(&cVar_Y02uujw4, 0.2f);
  numBytes += cSlice_init(&cSlice_55xfpnti, 1, -1);
  numBytes += cVar_init_f(&cVar_f72vXSLM, 500.0f);
  numBytes += sVarf_init(&sVarf_WUr6BnDG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ciroSFWp, 600.0f);
  numBytes += cBinop_init(&cBinop_6rXHT7KW, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_z33QE8Q7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nNTUL8PY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_85MXhTsT, 600.0f);
  numBytes += cBinop_init(&cBinop_auJjgDuR, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_FG2fuiGx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6mKWfkcg, 4000.0f);
  numBytes += cBinop_init(&cBinop_tqHSJGON, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wNHqX7AG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YQdUPxPp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_200mAezC, 4000.0f);
  numBytes += cBinop_init(&cBinop_bIEaoVzm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ln00Kr2x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7SlQm7NT, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_72eh65wV, false);
  numBytes += cBinop_init(&cBinop_tcuZUWat, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_xc8rPMR9, 20.0f);
  numBytes += cBinop_init(&cBinop_9BRro1C7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HQghlH9Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_opO13Pww, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IziHBJrK, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_myxXX98C, false);
  numBytes += cBinop_init(&cBinop_wu7yQTRl, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_PvqehwdS, 20.0f);
  numBytes += cBinop_init(&cBinop_JqfV5OLs, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_eN0RH2FW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P5qE9dVf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e8WCIrK3, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_83ISb95I, 1, -1);
  numBytes += cVar_init_f(&cVar_GAEOp89w, 0.25f);
  numBytes += cDelay_init(this, &cDelay_saSRNedJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bbcBQoVu, 0.0f);
  numBytes += hTable_init(&hTable_14y3n6lS, 256);
  numBytes += cTabhead_init(&cTabhead_IiVFJpOc, &hTable_14y3n6lS);
  numBytes += cVar_init_s(&cVar_ooHG4pu4, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_UyRd2k8I, 0.0f);
  numBytes += cDelay_init(this, &cDelay_MsQtnHLV, 0.0f);
  numBytes += cBinop_init(&cBinop_pE4K1zTa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vYKbaIVi, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_3mjEw0Em, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_wd7ZGKBJ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_XG3xF2zZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dMdFq9sy, 0.0f);
  numBytes += hTable_init(&hTable_6v0TUFb4, 256);
  numBytes += cTabhead_init(&cTabhead_ha4NXJFC, &hTable_6v0TUFb4);
  numBytes += cVar_init_s(&cVar_xr0amzKT, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_Xjybfjba, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8MDbedaw, 0.0f);
  numBytes += cBinop_init(&cBinop_bHSmIMwS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_veHCedhm, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_UyHX0Jrc, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_b5zc4uXv, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_Vh32kgeY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s8yq2HGa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_avJmLMxX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qNmzh4Bm, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_3EdSHWvE, 1, -1);
  numBytes += cVar_init_f(&cVar_0JRyog2e, 0.5f);
  numBytes += cSlice_init(&cSlice_cFOeZCo5, 1, -1);
  numBytes += cVar_init_f(&cVar_Sf9cDpV6, 0.2f);
  numBytes += cSlice_init(&cSlice_B9jhZON6, 1, -1);
  numBytes += cVar_init_f(&cVar_J7XYPB7d, 500.0f);
  numBytes += sVarf_init(&sVarf_dh5GWp7q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HyOoQTG2, 600.0f);
  numBytes += cBinop_init(&cBinop_rKls0qJP, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_lZJ2qzKt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X4fN5Y2L, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_83Aqljyc, 600.0f);
  numBytes += cBinop_init(&cBinop_eh04Qdg3, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_W4fyXXpU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yqMxRPMY, 4000.0f);
  numBytes += cBinop_init(&cBinop_TfKjKV6c, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_S3OKdy2M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nrESerZN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oIozDihk, 4000.0f);
  numBytes += cBinop_init(&cBinop_NIGuyCFD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ypNloANd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pMFSKvRq, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_2nnnOLdY, false);
  numBytes += cBinop_init(&cBinop_MhpiftwI, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_LF0cb9pe, 20.0f);
  numBytes += cBinop_init(&cBinop_ofuLKfuE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HnTmPoHQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BftbGXW0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rIHauaqU, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_GrKm3dwN, false);
  numBytes += cBinop_init(&cBinop_RRKoGlmU, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_BupxHVXU, 20.0f);
  numBytes += cBinop_init(&cBinop_4pLrGngd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5zY9b8d7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GYe8vt10, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C9mlg7bP, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_k5KG8Dfm, 1, -1);
  numBytes += cVar_init_f(&cVar_xdQtQVLE, 0.25f);
  numBytes += cDelay_init(this, &cDelay_gwv6jczt, 0.0f);
  numBytes += cDelay_init(this, &cDelay_EAQZemfZ, 0.0f);
  numBytes += hTable_init(&hTable_bLZK9s7Q, 256);
  numBytes += cTabhead_init(&cTabhead_kfkfjS5G, &hTable_bLZK9s7Q);
  numBytes += cVar_init_s(&cVar_iMMUUyyV, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_MNypWIWy, 0.0f);
  numBytes += cDelay_init(this, &cDelay_a6U7fWdW, 0.0f);
  numBytes += cBinop_init(&cBinop_h0Op2nec, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bf5ik0Ah, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_CRaFRaio, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5gWQHRif, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Dkc7wLSw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FPMau9th, 0.0f);
  numBytes += hTable_init(&hTable_wQW2h6MV, 256);
  numBytes += cTabhead_init(&cTabhead_IMZ4GTPp, &hTable_wQW2h6MV);
  numBytes += cVar_init_s(&cVar_CttQjvSn, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_wn5rbseH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Bghc1LeD, 0.0f);
  numBytes += cBinop_init(&cBinop_VhCdQTQM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a2vZPkr5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Gu6t0zMO, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_kpEEfQi4, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_XfjXisw4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DzIoH3I9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fkkULfn8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d0OuCppX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Shlzu8rs, 1.0f);
  numBytes += cIf_init(&cIf_02423VRz, false);
  numBytes += cIf_init(&cIf_CBB6tHb8, false);
  numBytes += cVar_init_f(&cVar_eatG82sW, 0.0f);
  numBytes += cVar_init_f(&cVar_Fw2Nui99, 0.0f);
  numBytes += cVar_init_f(&cVar_W9JWYsQr, 1.0f);
  numBytes += cIf_init(&cIf_AnOPITcH, false);
  numBytes += cIf_init(&cIf_ZPl7FYg3, false);
  numBytes += cVar_init_f(&cVar_fcIUli0h, 0.0f);
  numBytes += cVar_init_f(&cVar_Jqw3Fv8C, 0.0f);
  numBytes += cVar_init_f(&cVar_e44EFCpz, 1.0f);
  numBytes += cIf_init(&cIf_fjMAGoob, false);
  numBytes += cIf_init(&cIf_oJgqKzrj, false);
  numBytes += cVar_init_f(&cVar_6Iv9SVuQ, 0.0f);
  numBytes += cVar_init_f(&cVar_bhi1km0g, 0.0f);
  numBytes += cVar_init_f(&cVar_ViVKAXKq, 60000.0f);
  numBytes += cVar_init_f(&cVar_7S3ffZzI, 500.0f);
  numBytes += cSlice_init(&cSlice_gI2k39Wv, 1, -1);
  numBytes += cSlice_init(&cSlice_OBs5IKqH, 1, -1);
  numBytes += cVar_init_f(&cVar_paOalqdM, 0.0f);
  numBytes += cIf_init(&cIf_UNli2rWo, false);
  numBytes += cBinop_init(&cBinop_vPXRXlNT, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_Wtg2SQfx, 120.0f);
  numBytes += cBinop_init(&cBinop_6PAQ8NN6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_nBkHbW7V, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_8OPjnpD7, 60000.0f);
  numBytes += cVar_init_f(&cVar_ca0mIoIX, 500.0f);
  numBytes += cSlice_init(&cSlice_xMIBLODs, 1, -1);
  numBytes += cSlice_init(&cSlice_P1s7pyjA, 1, -1);
  numBytes += cVar_init_f(&cVar_X0T5QCmg, 0.0f);
  numBytes += cIf_init(&cIf_kx3TFioN, false);
  numBytes += cBinop_init(&cBinop_DNxcND16, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_rcXfBBx8, 120.0f);
  numBytes += cBinop_init(&cBinop_nOqSRuta, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_nuupajjK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_K9EqvbVT, 60000.0f);
  numBytes += cVar_init_f(&cVar_JDJFY2fp, 500.0f);
  numBytes += cSlice_init(&cSlice_gTuknUUv, 1, -1);
  numBytes += cSlice_init(&cSlice_TbCSIczO, 1, -1);
  numBytes += cVar_init_f(&cVar_qktQjPbq, 0.0f);
  numBytes += cIf_init(&cIf_OIrhFDof, false);
  numBytes += cBinop_init(&cBinop_lr0zROs8, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_6Yzmzf8D, 120.0f);
  numBytes += cBinop_init(&cBinop_Sa7LNEOs, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_RHJhPDLg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_BrRiUQCK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_01eZnNo3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hdNWxOjP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7aHLPc0M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wsOSckws, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3qrdQB7U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T3U5iiYe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_olvbRCvs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S5p8NP6v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4rPOSZxG, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_oPREYVrW);
  sEnv_free(&sEnv_LhHr4qYi);
  sEnv_free(&sEnv_nE6lbdBw);
  sEnv_free(&sEnv_7QKfknxM);
  sEnv_free(&sEnv_8NFZ0dcN);
  sEnv_free(&sEnv_zq3ROpKc);
  hTable_free(&hTable_eoPEpddH);
  hTable_free(&hTable_Cqyzl2Nl);
  hTable_free(&hTable_14y3n6lS);
  hTable_free(&hTable_6v0TUFb4);
  hTable_free(&hTable_bLZK9s7Q);
  hTable_free(&hTable_wQW2h6MV);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_eoPEpddH; // del-1349-delayL
    case 0x19A00729: return &hTable_Cqyzl2Nl; // del-1349-delayR
    case 0x584C8281: return &hTable_14y3n6lS; // del-1428-delayL
    case 0x54BF59F6: return &hTable_6v0TUFb4; // del-1428-delayR
    case 0xBCE693A: return &hTable_bLZK9s7Q; // del-1507-delayL
    case 0x95A380B3: return &hTable_wQW2h6MV; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y3V4f5UI_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qfuJO66B_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hN56lwLO_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iISwT6hm_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ovy3Yxn4_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UCZ6JhIg_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_74C6oiWz_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c9ZJDBcS_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JxeXTe9Q_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K8VM2pvO_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S2bOh4s0_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s8TLXM40_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aUHNEsNd_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nyiVPmoD_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Eg0TPgaG_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AmybYhAm_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dLzcI2Sy_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ATcPJ9v4_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a4q4uLgh_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aLiEduHR_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hwWLwcB6_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9qsab6jl_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wwgSTt6C_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d1Zln7jT_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yKRQm83L_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3dqZyNzs_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wIl0hDwI_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZfQgwXm7_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a8dGpp3J_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f6P0fv8z_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_83WpDu5g_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HSrLVAWM_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MGwZhSzi_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dw3Njss2_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gim0s1Ta_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GNHq3hlT_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vP35XqAz_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zrBmv9We_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sk0KdA17_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o5hkpmXB_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9hZYS9AS_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MK1tHD6Z_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vxs2tsSV_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WbM8mQ8m_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BvEpP4OH_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uAI1rzWB_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sF5pUPnX_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Kg1W4zpd_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4mbzMfq8_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MZnbM4zN_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kK3yICrs_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AknuaiHm_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7VCpA57F_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XQlQgDH1_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ahN7HzQR_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qi5ka4dG_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mJEBV4pf_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1ZkOiKJK_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wPqtdMjt_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_71f3sNBW_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QIaTxKyR_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zyja7CDo_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RhvwIogT_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GLA5nnEH_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_SC554AVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zxJtCvP1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RnxCcW47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rjSTXyyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_fnK7XIqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P9CZWJVV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_bRDBtdpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k1H2LDST_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BitD6B2n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GxUm2qwM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y4LbWRCT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_r1T1mQVQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qYHmi3YG, 0, m, &cSlice_qYHmi3YG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2ya8E1ol_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qYHmi3YG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sLFtd6bz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sLFtd6bz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_H7ZuMtp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sLFtd6bz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_sLFtd6bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yKRQm83L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_AXMVPglc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mWfwgQBt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_FQM1UkKA, 0, m, &cIf_FQM1UkKA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_FQM1UkKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DXv4mrNj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_t00FDmjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0G9yZHlX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_a0ldLgKn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_N5cIDx75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HI48ehm4, HV_BINOP_POW, 0, m, &cBinop_HI48ehm4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HI48ehm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_leKdk4Ee, 0, m, &cIf_leKdk4Ee_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yhWQtgP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DKaKHRNC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VctzjJMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t00FDmjB, 0, m, &cIf_t00FDmjB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lpAqA6Dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XAdyxym3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XAdyxym3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t00FDmjB, 1, m, &cIf_t00FDmjB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a0ldLgKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yhWQtgP0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0G9yZHlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_leKdk4Ee, 0, m, &cIf_leKdk4Ee_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DKaKHRNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HI48ehm4, HV_BINOP_POW, 1, m, &cBinop_HI48ehm4_sendMessage);
  cMsg_N5cIDx75_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_leKdk4Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jS5QTFbf, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mWfwgQBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FQM1UkKA, 1, m, &cIf_FQM1UkKA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DXv4mrNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2335brts, HV_BINOP_GREATER_THAN, 1, m, &cBinop_2335brts_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bEFtJkxN, HV_BINOP_EQ, 1, m, &cBinop_bEFtJkxN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KMqSDokW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmVspfC6, HV_BINOP_ADD, 0, m, &cBinop_HmVspfC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HmVspfC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lpAqA6Dl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VctzjJMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2335brts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_leKdk4Ee, 1, m, &cIf_leKdk4Ee_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bEFtJkxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MIPXqLxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_MIPXqLxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jS5QTFbf, m);
}

void Heavy_WSTD_DL3Y::cCast_kJcKavH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AXMVPglc, 0, m, &cVar_AXMVPglc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1rXWmpkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmVspfC6, HV_BINOP_ADD, 1, m, &cBinop_HmVspfC6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2335brts, HV_BINOP_GREATER_THAN, 0, m, &cBinop_2335brts_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bEFtJkxN, HV_BINOP_EQ, 0, m, &cBinop_bEFtJkxN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9Rasn9x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KMqSDokW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BPDWe5hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LCRHrf6v_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_bMtgyKFr, 0, m, &cIf_bMtgyKFr_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_bMtgyKFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kV5C3auL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_CGgt95RA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vsqV2hQG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OkXdp78m_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FmsQO9EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbfVmDMs, HV_BINOP_POW, 0, m, &cBinop_JbfVmDMs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JbfVmDMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cw3G3pAD, 0, m, &cIf_Cw3G3pAD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J2rWMCtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_FD1MynRf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ighjt87P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_32CM7yYU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CuTHP6kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CGgt95RA, 0, m, &cIf_CGgt95RA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_32CM7yYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CGgt95RA, 1, m, &cIf_CGgt95RA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OkXdp78m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_J2rWMCtP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vsqV2hQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Cw3G3pAD, 0, m, &cIf_Cw3G3pAD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FD1MynRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbfVmDMs, HV_BINOP_POW, 1, m, &cBinop_JbfVmDMs_sendMessage);
  cMsg_FmsQO9EO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Cw3G3pAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_10HymZvY_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jqaEYUTl_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_lnywVsHk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_LCRHrf6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bMtgyKFr, 1, m, &cIf_bMtgyKFr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kV5C3auL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H844BK8J, HV_BINOP_GREATER_THAN, 1, m, &cBinop_H844BK8J_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VAuOjzHd, HV_BINOP_EQ, 1, m, &cBinop_VAuOjzHd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QbhXLeQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_70BPZK40, HV_BINOP_ADD, 0, m, &cBinop_70BPZK40_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_70BPZK40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ighjt87P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CuTHP6kr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H844BK8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cw3G3pAD, 1, m, &cIf_Cw3G3pAD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VAuOjzHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rN7eBvi7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_rN7eBvi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_10HymZvY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jqaEYUTl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_lnywVsHk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4oQOQ4mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BPDWe5hd, 0, m, &cVar_BPDWe5hd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Cl45ItE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QbhXLeQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JM4obH7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_70BPZK40, HV_BINOP_ADD, 1, m, &cBinop_70BPZK40_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H844BK8J, HV_BINOP_GREATER_THAN, 0, m, &cBinop_H844BK8J_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VAuOjzHd, HV_BINOP_EQ, 0, m, &cBinop_VAuOjzHd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QSA0i7qf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7eejJcul_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_q3uAo5ne, 0, m, &cIf_q3uAo5ne_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_q3uAo5ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4AAWWsGW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_QaELfDZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Wb4PPOk0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Z3urE3ji_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Nw7TJZMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EP3nihfM, HV_BINOP_POW, 0, m, &cBinop_EP3nihfM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EP3nihfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kgu3WcZU, 0, m, &cIf_kgu3WcZU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gcVt2lg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_G34d8MSb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xGI5r7Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_omT8y3CW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jdFxrruf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaELfDZw, 0, m, &cIf_QaELfDZw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_omT8y3CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaELfDZw, 1, m, &cIf_QaELfDZw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z3urE3ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gcVt2lg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wb4PPOk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kgu3WcZU, 0, m, &cIf_kgu3WcZU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G34d8MSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EP3nihfM, HV_BINOP_POW, 1, m, &cBinop_EP3nihfM_sendMessage);
  cMsg_Nw7TJZMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_kgu3WcZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_9r1mZhI3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_7eejJcul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q3uAo5ne, 1, m, &cIf_q3uAo5ne_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4AAWWsGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upjeIQsP, HV_BINOP_GREATER_THAN, 1, m, &cBinop_upjeIQsP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aRmbEhYG, HV_BINOP_EQ, 1, m, &cBinop_aRmbEhYG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wxBO6k43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3nAepmZf, HV_BINOP_ADD, 0, m, &cBinop_3nAepmZf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3nAepmZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xGI5r7Hn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jdFxrruf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_upjeIQsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kgu3WcZU, 1, m, &cIf_kgu3WcZU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aRmbEhYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kv3Rndsr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_kv3Rndsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9r1mZhI3, m);
}

void Heavy_WSTD_DL3Y::cCast_XmeBrUeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QSA0i7qf, 0, m, &cVar_QSA0i7qf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_86F8pIp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wxBO6k43_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qysMgYVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3nAepmZf, HV_BINOP_ADD, 1, m, &cBinop_3nAepmZf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_upjeIQsP, HV_BINOP_GREATER_THAN, 0, m, &cBinop_upjeIQsP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aRmbEhYG, HV_BINOP_EQ, 0, m, &cBinop_aRmbEhYG_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_giMiNWsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_K0NY6jWp, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_KpkOgGQ5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rxPVpsRX, 0, m, &cSlice_rxPVpsRX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_s07X54Zc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_rxPVpsRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_itLVzWWf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_itLVzWWf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_541IzmcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_itLVzWWf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_itLVzWWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wwgSTt6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_s07X54Zc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_f8Pm0LkZ, 0, m, &cSlice_f8Pm0LkZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_r1T1mQVQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_f8Pm0LkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Sm1L6Ma2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Sm1L6Ma2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_I9sCI1nX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Sm1L6Ma2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Sm1L6Ma2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wIl0hDwI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2ya8E1ol_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FB2Opo51, 0, m, &cSlice_FB2Opo51_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FZaKMWdd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FB2Opo51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EjfxYnvZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EjfxYnvZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_sQCsvcCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EjfxYnvZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EjfxYnvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_d1Zln7jT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_FZaKMWdd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nByURFxS, 0, m, &cSlice_nByURFxS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_nByURFxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0KItCPh1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0KItCPh1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_m3jLGELn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0KItCPh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0KItCPh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3dqZyNzs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_B6YBzdOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6NSQsth5, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FjlRSSHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Owg2YtKz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ISyhrbGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CrisXiUv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_L7hrGUj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RwU0CIMw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wIOQZnPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NKOtsfnR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CRcXX2hJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dnTEANRK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dnTEANRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zkeAGwZ7, HV_BINOP_DIVIDE, 1, m, &cBinop_zkeAGwZ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vCRkZPfN_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_NbbEzq8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dXSClebN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tBwBYPjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_NbbEzq8n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dXSClebN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zkeAGwZ7, HV_BINOP_DIVIDE, 0, m, &cBinop_zkeAGwZ7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vCRkZPfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tBwBYPjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zkeAGwZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NeC5MsOl, HV_BINOP_MULTIPLY, 1, m, &cBinop_NeC5MsOl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NeC5MsOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AqZhpLgx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YPdfpsrW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ojGZoKyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XHSL7IzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_Ex3kLdte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i2N0kXTm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RUoNJNdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2BJGMxca_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2BJGMxca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NeC5MsOl, HV_BINOP_MULTIPLY, 0, m, &cBinop_NeC5MsOl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F3mhn59i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_foAXsGJ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_foAXsGJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rDTI80EZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CPSRCz7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FQAtCmYa, 1, m, &cVar_FQAtCmYa_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FQAtCmYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_galQqunl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vVMf3C1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VPYErsXg, HV_BINOP_MULTIPLY, 1, m, &cBinop_VPYErsXg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_43Zo6DQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vVMf3C1b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oUZT6j3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_01UbHnSz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_01UbHnSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HuPWP6ov, HV_BINOP_MULTIPLY, 1, m, &cBinop_HuPWP6ov_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VXRbkaHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7xKexFP, HV_BINOP_MULTIPLY, 1, m, &cBinop_x7xKexFP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JRgyMGZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VXRbkaHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0R4Pbetq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nC5DHLIu, HV_BINOP_MULTIPLY, 1, m, &cBinop_nC5DHLIu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bLN3Jutr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AAdZDTu4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AAdZDTu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aFWibs4h, HV_BINOP_MULTIPLY, 1, m, &cBinop_aFWibs4h_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zAO2NJyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o4E7dqW2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_RUoNJNdL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyNX4sXd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tteUS2mF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_F3mhn59i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YPdfpsrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Ex3kLdte_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AqZhpLgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ojGZoKyI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_XHSL7IzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f6P0fv8z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_i2N0kXTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_a8dGpp3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zRS7DKjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZfQgwXm7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_rDTI80EZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hcj997sl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hcj997sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rnh85uyo, HV_BINOP_MULTIPLY, 1, m, &cBinop_rnh85uyo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rnh85uyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cs6FzVMP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cs6FzVMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zRS7DKjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_galQqunl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gQmpgtNl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gQmpgtNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6jzquehy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Es76Z0TU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_67Sk1ZZF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3ynUDIvO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Insq1ZZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s9GWFrXO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VPYErsXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B6YBzdOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HuPWP6ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FjlRSSHb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_x7xKexFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ISyhrbGX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nC5DHLIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L7hrGUj3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aFWibs4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wIOQZnPA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_E787f2vJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zAO2NJyR, 0, m, &cVar_zAO2NJyR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fd2kv7wB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tteUS2mF, 1, m, &cVar_tteUS2mF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3ynUDIvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7xKexFP, HV_BINOP_MULTIPLY, 0, m, &cBinop_x7xKexFP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6jzquehy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_s9GWFrXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VPYErsXg, HV_BINOP_MULTIPLY, 0, m, &cBinop_VPYErsXg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_67Sk1ZZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nC5DHLIu, HV_BINOP_MULTIPLY, 0, m, &cBinop_nC5DHLIu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Insq1ZZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HuPWP6ov, HV_BINOP_MULTIPLY, 0, m, &cBinop_HuPWP6ov_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Es76Z0TU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aFWibs4h, HV_BINOP_MULTIPLY, 0, m, &cBinop_aFWibs4h_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_o4E7dqW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tteUS2mF, 0, m, &cVar_tteUS2mF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iyNX4sXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FQAtCmYa, 0, m, &cVar_FQAtCmYa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tjOi2Ecg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FVJBk0wk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dVUTDo5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rhOeetHW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_peWYpvLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tMhboijr, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9S4gojKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wnf6PQ95, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JcbDliDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qS1jfq4H_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_qS1jfq4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hfhjymdp, HV_BINOP_DIVIDE, 1, m, &cBinop_hfhjymdp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VWy5aLW6_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_qX4hqGD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GHsdyl96_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UCcHvxxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_qX4hqGD7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHsdyl96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hfhjymdp, HV_BINOP_DIVIDE, 0, m, &cBinop_hfhjymdp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VWy5aLW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UCcHvxxP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hfhjymdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GY2AvWfW, HV_BINOP_MULTIPLY, 1, m, &cBinop_GY2AvWfW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GY2AvWfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e8F8fl3f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUoOT5sD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_XRlxmj2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wU12jqHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_kdNJXNf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1ghthRGH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0ZUy0QM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_TBaZQsuo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TBaZQsuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GY2AvWfW, HV_BINOP_MULTIPLY, 0, m, &cBinop_GY2AvWfW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mIvbIT0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6p3lbWEy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6p3lbWEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DPH4wPqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SIP994M6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_svzfppeX, HV_BINOP_MULTIPLY, 1, m, &cBinop_svzfppeX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T6ANuB8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tpUgxlnJ, 1, m, &cVar_tpUgxlnJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3SAOsZ1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_95gWsrk9, HV_BINOP_MULTIPLY, 1, m, &cBinop_95gWsrk9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9mdVk3oH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uiqwTN4o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uiqwTN4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jsxZ4jO6, HV_BINOP_MULTIPLY, 1, m, &cBinop_jsxZ4jO6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tpUgxlnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_20JctxnJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YfmffLRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5jBFgXV5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_0ZUy0QM3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zOMgAtmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MMjGGbTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mIvbIT0R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GUoOT5sD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_kdNJXNf4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e8F8fl3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_XRlxmj2J_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_wU12jqHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MGwZhSzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1ghthRGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HSrLVAWM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_c2D4n4TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_83WpDu5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_DPH4wPqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LezHli1L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LezHli1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxpROE4D, HV_BINOP_MULTIPLY, 1, m, &cBinop_bxpROE4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bxpROE4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QixRvNuM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QixRvNuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c2D4n4TE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_20JctxnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bTmRTRoz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bTmRTRoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C2670qYJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BmEJLg4o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VDAfXU0B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iwjwjvHl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UZds6qLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tjOi2Ecg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_svzfppeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dVUTDo5x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_95gWsrk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_peWYpvLv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jsxZ4jO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9S4gojKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UL35I3O5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YfmffLRQ, 0, m, &cVar_YfmffLRQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K9wVXyYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MMjGGbTL, 1, m, &cVar_MMjGGbTL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zOMgAtmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tpUgxlnJ, 0, m, &cVar_tpUgxlnJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5jBFgXV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MMjGGbTL, 0, m, &cVar_MMjGGbTL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iwjwjvHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZds6qLQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_UZds6qLQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C2670qYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jsxZ4jO6, HV_BINOP_MULTIPLY, 0, m, &cBinop_jsxZ4jO6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VDAfXU0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_svzfppeX, HV_BINOP_MULTIPLY, 0, m, &cBinop_svzfppeX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BmEJLg4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_95gWsrk9, HV_BINOP_MULTIPLY, 0, m, &cBinop_95gWsrk9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_errzrx76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uiccnkjz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5WspHqGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rEfFKhb3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LrfEdmfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CR715b1u, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_roWuCZt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7AsExIOX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ssQDdt9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dDmxEGbs, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pGCgz5SD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ULEVkkzr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ULEVkkzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gst6Hh8V, HV_BINOP_DIVIDE, 1, m, &cBinop_Gst6Hh8V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_98XGtKdi_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_0GTgSZb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fF15suQN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2FdeLWEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_0GTgSZb6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fF15suQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gst6Hh8V, HV_BINOP_DIVIDE, 0, m, &cBinop_Gst6Hh8V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_98XGtKdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2FdeLWEU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Gst6Hh8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E5JI0cUl, HV_BINOP_MULTIPLY, 1, m, &cBinop_E5JI0cUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E5JI0cUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c3Esbbjd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ClSwRSF2_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_GdfvE9ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7uz4hklT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_5DUDtIG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RNOd42yT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LoH5A12I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qnmuEtOO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qnmuEtOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E5JI0cUl, HV_BINOP_MULTIPLY, 0, m, &cBinop_E5JI0cUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gMLR8wQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_BiQpGw9m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BiQpGw9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cKWGJuOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_x0yMIxjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ByfQrqQw, HV_BINOP_MULTIPLY, 1, m, &cBinop_ByfQrqQw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pNauEZ7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1acORzx5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1acORzx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_x0yMIxjm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NFx5XSda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sXi3qxM2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sXi3qxM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DJas8FSS, HV_BINOP_MULTIPLY, 1, m, &cBinop_DJas8FSS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Uk5f1bLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMJwuuwZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_tMJwuuwZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xdw3ND6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vmCAteu4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vmCAteu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Uk5f1bLR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GjpduVuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OhoStdq7, 1, m, &cVar_OhoStdq7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TLny2OUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aXl76tzq, HV_BINOP_MULTIPLY, 1, m, &cBinop_aXl76tzq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lX32cwk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7nAviw6K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7nAviw6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1nnMRrWK, HV_BINOP_MULTIPLY, 1, m, &cBinop_1nnMRrWK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_OhoStdq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p5Hkqedf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_dRnx8aOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VyuvvAGm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_LoH5A12I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C9E45197_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ml7FwYMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gMLR8wQv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ClSwRSF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5DUDtIG7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c3Esbbjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_GdfvE9ny_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_7uz4hklT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GNHq3hlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_RNOd42yT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gim0s1Ta_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_wGQQ8XLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Dw3Njss2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_cKWGJuOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aQSVKAXn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aQSVKAXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cxZYBH5W, HV_BINOP_MULTIPLY, 1, m, &cBinop_cxZYBH5W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cxZYBH5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yux1zPBy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yux1zPBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wGQQ8XLO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_p5Hkqedf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FCsmABdk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FCsmABdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k0UUopQj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A2XYiHJB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pa9w5i0d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D4SWLfgx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p5tJTjh1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZunkYNB9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ByfQrqQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_errzrx76_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DJas8FSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5WspHqGP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tMJwuuwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LrfEdmfv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aXl76tzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_roWuCZt1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1nnMRrWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ssQDdt9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eEvcoepr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dRnx8aOy, 0, m, &cVar_dRnx8aOy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9Qxw41QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ml7FwYMR, 1, m, &cVar_Ml7FwYMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_p5tJTjh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DJas8FSS, HV_BINOP_MULTIPLY, 0, m, &cBinop_DJas8FSS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A2XYiHJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1nnMRrWK, HV_BINOP_MULTIPLY, 0, m, &cBinop_1nnMRrWK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D4SWLfgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMJwuuwZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_tMJwuuwZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_k0UUopQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_ZunkYNB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ByfQrqQw, HV_BINOP_MULTIPLY, 0, m, &cBinop_ByfQrqQw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Pa9w5i0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aXl76tzq, HV_BINOP_MULTIPLY, 0, m, &cBinop_aXl76tzq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C9E45197_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OhoStdq7, 0, m, &cVar_OhoStdq7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VyuvvAGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ml7FwYMR, 0, m, &cVar_Ml7FwYMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_10HymZvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_giMiNWsU, 1, m, &cIf_giMiNWsU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0dYW98iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_K0NY6jWp, m);
}

void Heavy_WSTD_DL3Y::cBinop_jqaEYUTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0dYW98iQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lnywVsHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_giMiNWsU, 0, m, &cIf_giMiNWsU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Nq1m9Tr7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_12G0qa0T, 0, m, &cSlice_12G0qa0T_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rNZgR9pX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_12G0qa0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EhkWhBPI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EhkWhBPI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_UP364Jyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EhkWhBPI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EhkWhBPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sk0KdA17_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_qGgWQH7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_glkvo6eF_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tN5EqYgx, 0, m, &cIf_tN5EqYgx_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tN5EqYgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PbzVaUZC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_TyxUX38s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0Sikmami_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_AIAxR04U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_cxI6P8W4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZr1OJUd, HV_BINOP_POW, 0, m, &cBinop_AZr1OJUd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AZr1OJUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POSNXZWP, 0, m, &cIf_POSNXZWP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZBFqpBFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9yS9sygh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ASA80Adj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TyxUX38s, 0, m, &cIf_TyxUX38s_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LmYn9hg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oKnKuC51_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oKnKuC51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TyxUX38s, 1, m, &cIf_TyxUX38s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AIAxR04U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZBFqpBFd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0Sikmami_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_POSNXZWP, 0, m, &cIf_POSNXZWP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9yS9sygh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZr1OJUd, HV_BINOP_POW, 1, m, &cBinop_AZr1OJUd_sendMessage);
  cMsg_cxI6P8W4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_POSNXZWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Z9hG7now, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_glkvo6eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tN5EqYgx, 1, m, &cIf_tN5EqYgx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PbzVaUZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AhpQglRZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_AhpQglRZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dTF1Ug57, HV_BINOP_EQ, 1, m, &cBinop_dTF1Ug57_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WUBBMtmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bpWXLPOz, HV_BINOP_ADD, 0, m, &cBinop_bpWXLPOz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bpWXLPOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LmYn9hg7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ASA80Adj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AhpQglRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POSNXZWP, 1, m, &cIf_POSNXZWP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dTF1Ug57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kj0Bjkmr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Kj0Bjkmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z9hG7now, m);
}

void Heavy_WSTD_DL3Y::cCast_eDNG5AUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WUBBMtmq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rjNcSWZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bpWXLPOz, HV_BINOP_ADD, 1, m, &cBinop_bpWXLPOz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AhpQglRZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_AhpQglRZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dTF1Ug57, HV_BINOP_EQ, 0, m, &cBinop_dTF1Ug57_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rJV7vtTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qGgWQH7u, 0, m, &cVar_qGgWQH7u_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fjGqHcH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TDIfWfTZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Z8h5OheN, 0, m, &cIf_Z8h5OheN_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Z8h5OheN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rgnHuEPZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_PfstLl1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_slF4DhFX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VTcYaQQf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_UiM6DfG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7eSUd7x, HV_BINOP_POW, 0, m, &cBinop_B7eSUd7x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B7eSUd7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0jJQ5LIS, 0, m, &cIf_0jJQ5LIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gGgWNYTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_7dINeyu5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GwtstKkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1cmq1cdK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jzL9Pa6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PfstLl1A, 0, m, &cIf_PfstLl1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1cmq1cdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PfstLl1A, 1, m, &cIf_PfstLl1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VTcYaQQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gGgWNYTB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_slF4DhFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0jJQ5LIS, 0, m, &cIf_0jJQ5LIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7dINeyu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7eSUd7x, HV_BINOP_POW, 1, m, &cBinop_B7eSUd7x_sendMessage);
  cMsg_UiM6DfG3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_0jJQ5LIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oGthxMy1_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LCAghbu4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_oFiWbpGx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_TDIfWfTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z8h5OheN, 1, m, &cIf_Z8h5OheN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rgnHuEPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RNsDt8IS, HV_BINOP_GREATER_THAN, 1, m, &cBinop_RNsDt8IS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqdTp0TX, HV_BINOP_EQ, 1, m, &cBinop_rqdTp0TX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GImCNRpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_52nhWNAA, HV_BINOP_ADD, 0, m, &cBinop_52nhWNAA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_52nhWNAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GwtstKkK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jzL9Pa6j_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RNsDt8IS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0jJQ5LIS, 1, m, &cIf_0jJQ5LIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rqdTp0TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7TLCways_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7TLCways_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oGthxMy1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LCAghbu4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_oFiWbpGx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iTTGh138_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fjGqHcH3, 0, m, &cVar_fjGqHcH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tpUKG4Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GImCNRpJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_L6O2nhht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_52nhWNAA, HV_BINOP_ADD, 1, m, &cBinop_52nhWNAA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RNsDt8IS, HV_BINOP_GREATER_THAN, 0, m, &cBinop_RNsDt8IS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqdTp0TX, HV_BINOP_EQ, 0, m, &cBinop_rqdTp0TX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AUYb7yyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IYQl9xcz_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WnrwoVkA, 0, m, &cIf_WnrwoVkA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_WnrwoVkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SMGvtWvX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_AUK1w4La_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Bt5z22ib_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Lp6HxZUq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_wPBWcnSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIp9lapY, HV_BINOP_POW, 0, m, &cBinop_hIp9lapY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hIp9lapY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yYz54qVC, 0, m, &cIf_yYz54qVC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TB92tsqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2jl2exfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YFW5goeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AUK1w4La, 0, m, &cIf_AUK1w4La_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2tGdmsht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SdpCrWo8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SdpCrWo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AUK1w4La, 1, m, &cIf_AUK1w4La_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lp6HxZUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TB92tsqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Bt5z22ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_yYz54qVC, 0, m, &cIf_yYz54qVC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2jl2exfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIp9lapY, HV_BINOP_POW, 1, m, &cBinop_hIp9lapY_sendMessage);
  cMsg_wPBWcnSl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_yYz54qVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_2Yis95YL, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_IYQl9xcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WnrwoVkA, 1, m, &cIf_WnrwoVkA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SMGvtWvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7jpuvpl, HV_BINOP_GREATER_THAN, 1, m, &cBinop_h7jpuvpl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DG9IvLgC, HV_BINOP_EQ, 1, m, &cBinop_DG9IvLgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_25uQCyoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1avPN1sW, HV_BINOP_ADD, 0, m, &cBinop_1avPN1sW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1avPN1sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2tGdmsht_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFW5goeF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h7jpuvpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yYz54qVC, 1, m, &cIf_yYz54qVC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DG9IvLgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XJRXjtEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_XJRXjtEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2Yis95YL, m);
}

void Heavy_WSTD_DL3Y::cCast_w8sHjuN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_25uQCyoQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Xuh3OQ9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1avPN1sW, HV_BINOP_ADD, 1, m, &cBinop_1avPN1sW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7jpuvpl, HV_BINOP_GREATER_THAN, 0, m, &cBinop_h7jpuvpl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DG9IvLgC, HV_BINOP_EQ, 0, m, &cBinop_DG9IvLgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KKFF1iRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AUYb7yyj, 0, m, &cVar_AUYb7yyj_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_cOFFGsTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BUwGMNzP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_R26KDCdc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_42QxJ8Ew, 0, m, &cSlice_42QxJ8Ew_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GjK7vMLz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_42QxJ8Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9RrTVJhG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9RrTVJhG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Vmhoq3vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9RrTVJhG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9RrTVJhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vP35XqAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GjK7vMLz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4aztasWQ, 0, m, &cSlice_4aztasWQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Nq1m9Tr7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_4aztasWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hPNCnJOf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hPNCnJOf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_iTjgMaCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hPNCnJOf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hPNCnJOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9hZYS9AS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rNZgR9pX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JbMAanxE, 0, m, &cSlice_JbMAanxE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xXW3eab7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_JbMAanxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BthICivm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BthICivm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_owLBvaTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BthICivm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BthICivm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zrBmv9We_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_xXW3eab7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fc5VyEVt, 0, m, &cSlice_fc5VyEVt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_fc5VyEVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kfOcU1ig_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kfOcU1ig_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_urrr3jAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kfOcU1ig_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kfOcU1ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o5hkpmXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_92N0Myit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1wsZQByj, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DIfuS6ks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_il55jxCz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Cn1SpG2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_814at4iS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6PRSfmbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DhO695Aq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ciU8KGRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7hO7PyUW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sxrRrA1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iTu3sKcC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_iTu3sKcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nbl6Jks, HV_BINOP_DIVIDE, 1, m, &cBinop_5nbl6Jks_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ju8U3xb6_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_U0AYB1dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dBum5OMp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kglUc0ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_U0AYB1dd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dBum5OMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5nbl6Jks, HV_BINOP_DIVIDE, 0, m, &cBinop_5nbl6Jks_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ju8U3xb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kglUc0ez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5nbl6Jks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KAfnrLL0, HV_BINOP_MULTIPLY, 1, m, &cBinop_KAfnrLL0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KAfnrLL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ivw6fJua_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KwNTsoED_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_IePAGQXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ofs9UGsD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_uN48c9P8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EgrtIxct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fwMrrGgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2RXtnErY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2RXtnErY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KAfnrLL0, HV_BINOP_MULTIPLY, 0, m, &cBinop_KAfnrLL0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VpVeviNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YB3GO4Tq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YB3GO4Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KHKgkR8H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xvATCA32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kn9oKE4E, 1, m, &cVar_Kn9oKE4E_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Kn9oKE4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xNNAuMdq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DW5Zxb7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IincbQUd, HV_BINOP_MULTIPLY, 1, m, &cBinop_IincbQUd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rJXiGHAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DW5Zxb7e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j8bj0vki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tcSTz4qx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tcSTz4qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2y58kjVr, HV_BINOP_MULTIPLY, 1, m, &cBinop_2y58kjVr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NL0HURvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_en0SZbjB, HV_BINOP_MULTIPLY, 1, m, &cBinop_en0SZbjB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uZaq1K5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NL0HURvK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5DXiaoBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLC0BHqm, HV_BINOP_MULTIPLY, 1, m, &cBinop_XLC0BHqm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i9ThNRnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ssjEGWBO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ssjEGWBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YoDBwqLy, HV_BINOP_MULTIPLY, 1, m, &cBinop_YoDBwqLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lsICW6Ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_74a1xMga_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_fwMrrGgp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_elHUMJAz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8etnW6Wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VpVeviNk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KwNTsoED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_uN48c9P8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ivw6fJua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IePAGQXF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_ofs9UGsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WbM8mQ8m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EgrtIxct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vxs2tsSV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9fnOmgd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MK1tHD6Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KHKgkR8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5h67tfyA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5h67tfyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7xauLtuF, HV_BINOP_MULTIPLY, 1, m, &cBinop_7xauLtuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7xauLtuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8CjmRRtD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8CjmRRtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9fnOmgd9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xNNAuMdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tJs1TWam_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tJs1TWam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jX04mvLE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9zNmNFCP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YtZjZVXs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gAjOhwOa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CmDJxKhh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LXp8RuhR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IincbQUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92N0Myit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2y58kjVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DIfuS6ks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_en0SZbjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cn1SpG2S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XLC0BHqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6PRSfmbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YoDBwqLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ciU8KGRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GlBQBX7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8etnW6Wy, 1, m, &cVar_8etnW6Wy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UvoBwUfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lsICW6Ef, 0, m, &cVar_lsICW6Ef_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LXp8RuhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IincbQUd, HV_BINOP_MULTIPLY, 0, m, &cBinop_IincbQUd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YtZjZVXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLC0BHqm, HV_BINOP_MULTIPLY, 0, m, &cBinop_XLC0BHqm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CmDJxKhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2y58kjVr, HV_BINOP_MULTIPLY, 0, m, &cBinop_2y58kjVr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9zNmNFCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YoDBwqLy, HV_BINOP_MULTIPLY, 0, m, &cBinop_YoDBwqLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gAjOhwOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_en0SZbjB, HV_BINOP_MULTIPLY, 0, m, &cBinop_en0SZbjB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jX04mvLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_elHUMJAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kn9oKE4E, 0, m, &cVar_Kn9oKE4E_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_74a1xMga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8etnW6Wy, 0, m, &cVar_8etnW6Wy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0znfYLdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e0ohxC5o, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JQXQwrKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g1Ojihd3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SXzEEokX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sEv5FaSF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7xLsBMfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lv5LIyAk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2pEfwchv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OpVQwGwj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_OpVQwGwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zXlXCKJf, HV_BINOP_DIVIDE, 1, m, &cBinop_zXlXCKJf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L4Ab6wdr_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_XUJfjJfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Pu8kPoFp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YhPtXNaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_XUJfjJfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pu8kPoFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zXlXCKJf, HV_BINOP_DIVIDE, 0, m, &cBinop_zXlXCKJf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L4Ab6wdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YhPtXNaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zXlXCKJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qGfwP9ml, HV_BINOP_MULTIPLY, 1, m, &cBinop_qGfwP9ml_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qGfwP9ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RGhWrEId_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eYGnoBx1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_E4EcgZNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LB5evceG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_ABcsFy7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qhj0nil0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bxwhlC2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_4CwMYrW7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4CwMYrW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qGfwP9ml, HV_BINOP_MULTIPLY, 0, m, &cBinop_qGfwP9ml_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WR8n4xMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8EhMaDJa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8EhMaDJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ANJhudxj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gKSUXs6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NU6K6Hj, HV_BINOP_MULTIPLY, 1, m, &cBinop_3NU6K6Hj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gDazW3us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6odcXRuH, 1, m, &cVar_6odcXRuH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tf5siKUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oxOxfzft, HV_BINOP_MULTIPLY, 1, m, &cBinop_oxOxfzft_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gaCN01ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_m0J0gNIx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m0J0gNIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JdW8iSAJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_JdW8iSAJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_6odcXRuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JUqHD0xk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_5X7OaLsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NKGmOoJL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bxwhlC2r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hdAp80C9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_M3wupvgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_WR8n4xMZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eYGnoBx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ABcsFy7m_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RGhWrEId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_E4EcgZNS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_LB5evceG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sF5pUPnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qhj0nil0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uAI1rzWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PaU7rzeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BvEpP4OH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ANJhudxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4EPl0JBL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4EPl0JBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JIIfIUMj, HV_BINOP_MULTIPLY, 1, m, &cBinop_JIIfIUMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JIIfIUMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pXqA9Adf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pXqA9Adf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PaU7rzeB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JUqHD0xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TIH3fOlL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TIH3fOlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xPBkOWvr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1UMhPgHn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7YuN2iGd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZzUGaZSf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wXezlk8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0znfYLdP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3NU6K6Hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JQXQwrKw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oxOxfzft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SXzEEokX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JdW8iSAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7xLsBMfR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JNHWjv4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5X7OaLsT, 0, m, &cVar_5X7OaLsT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q9wXp1K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M3wupvgF, 1, m, &cVar_M3wupvgF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hdAp80C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6odcXRuH, 0, m, &cVar_6odcXRuH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NKGmOoJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M3wupvgF, 0, m, &cVar_M3wupvgF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZzUGaZSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wXezlk8R, HV_BINOP_MULTIPLY, 0, m, &cBinop_wXezlk8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xPBkOWvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JdW8iSAJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_JdW8iSAJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7YuN2iGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NU6K6Hj, HV_BINOP_MULTIPLY, 0, m, &cBinop_3NU6K6Hj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1UMhPgHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oxOxfzft, HV_BINOP_MULTIPLY, 0, m, &cBinop_oxOxfzft_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6a1nitOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MWHRS08p, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3aPNbcTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V3YKR3P2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Tz3vXDGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_35wh2VeU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FCd2mHqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FygbfStq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0OFs0LD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vaugzlV4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_p8byiyKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oYoCV5Nt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oYoCV5Nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGraqjmN, HV_BINOP_DIVIDE, 1, m, &cBinop_AGraqjmN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pHiVeY8J_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_MItmJW0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Y8jJpg3m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gmDmEvV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MItmJW0I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y8jJpg3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGraqjmN, HV_BINOP_DIVIDE, 0, m, &cBinop_AGraqjmN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pHiVeY8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gmDmEvV6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AGraqjmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8vJZ0iHb, HV_BINOP_MULTIPLY, 1, m, &cBinop_8vJZ0iHb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8vJZ0iHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NkkoypLk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cg6UrEqW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_yJgiwtyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b9biHHSN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_5nVAawHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c9R9qI4r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rbGcDUDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_J2Z22Cdm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J2Z22Cdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8vJZ0iHb, HV_BINOP_MULTIPLY, 0, m, &cBinop_8vJZ0iHb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y1s8uSD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_xWUlKEmV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xWUlKEmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jvjes1rU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HhLvQy1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IgeBzOyP, HV_BINOP_MULTIPLY, 1, m, &cBinop_IgeBzOyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e1sToFxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pIANO8jc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pIANO8jc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HhLvQy1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uSGSnH3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_27lvBjzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_27lvBjzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2cao4MtG, HV_BINOP_MULTIPLY, 1, m, &cBinop_2cao4MtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r6RFveKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Jq28Vw0, HV_BINOP_MULTIPLY, 1, m, &cBinop_1Jq28Vw0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kRTHF5tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jLpSQhaj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jLpSQhaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_r6RFveKQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CRUrVkcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7mHLRRZC, 1, m, &cVar_7mHLRRZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CowEW4Zg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C9HykDFU, HV_BINOP_MULTIPLY, 1, m, &cBinop_C9HykDFU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y4x9zrIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PR5EZvR7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PR5EZvR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9vakIZrP, HV_BINOP_MULTIPLY, 1, m, &cBinop_9vakIZrP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7mHLRRZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7QRKOGqG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Bor8zo2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vQvBvEdD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rbGcDUDn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oAAYjl4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nGU6olJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_y1s8uSD3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NkkoypLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yJgiwtyF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cg6UrEqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5nVAawHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_b9biHHSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MZnbM4zN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_c9R9qI4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4mbzMfq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_5QY7gdfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Kg1W4zpd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_jvjes1rU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6l3UWCQD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6l3UWCQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSZ7QY7q, HV_BINOP_MULTIPLY, 1, m, &cBinop_gSZ7QY7q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gSZ7QY7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dvvGzAJW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dvvGzAJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5QY7gdfF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7QRKOGqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2uS0H86T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2uS0H86T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eJ1Y5T43_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d1FsP9CR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FDlwzS5r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_msSkq2Dv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZB3C3pZH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ERrUZ1Pw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IgeBzOyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6a1nitOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2cao4MtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3aPNbcTi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1Jq28Vw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tz3vXDGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_C9HykDFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FCd2mHqz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9vakIZrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0OFs0LD3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ubFxuZ7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bor8zo2u, 0, m, &cVar_Bor8zo2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gedbAXiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nGU6olJ6, 1, m, &cVar_nGU6olJ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZB3C3pZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2cao4MtG, HV_BINOP_MULTIPLY, 0, m, &cBinop_2cao4MtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_d1FsP9CR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9vakIZrP, HV_BINOP_MULTIPLY, 0, m, &cBinop_9vakIZrP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_msSkq2Dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Jq28Vw0, HV_BINOP_MULTIPLY, 0, m, &cBinop_1Jq28Vw0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eJ1Y5T43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_ERrUZ1Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IgeBzOyP, HV_BINOP_MULTIPLY, 0, m, &cBinop_IgeBzOyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FDlwzS5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C9HykDFU, HV_BINOP_MULTIPLY, 0, m, &cBinop_C9HykDFU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oAAYjl4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7mHLRRZC, 0, m, &cVar_7mHLRRZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vQvBvEdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nGU6olJ6, 0, m, &cVar_nGU6olJ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oGthxMy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cOFFGsTt, 1, m, &cIf_cOFFGsTt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zv2ACX96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BUwGMNzP, m);
}

void Heavy_WSTD_DL3Y::cBinop_LCAghbu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zv2ACX96_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oFiWbpGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cOFFGsTt, 0, m, &cIf_cOFFGsTt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0Dis7dIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzpIap32, HV_BINOP_DIVIDE, 0, m, &cBinop_NzpIap32_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JQan1hwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ix12FAmE, HV_BINOP_DIVIDE, 1, m, &cBinop_ix12FAmE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NzpIap32, HV_BINOP_DIVIDE, 1, m, &cBinop_NzpIap32_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_d21ssCRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wl0R3NdN, HV_BINOP_DIVIDE, 0, m, &cBinop_Wl0R3NdN_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ddK004mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wl0R3NdN, HV_BINOP_DIVIDE, 1, m, &cBinop_Wl0R3NdN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BitD6B2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JQan1hwu, 0, m, &cVar_JQan1hwu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y4LbWRCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ix12FAmE, HV_BINOP_DIVIDE, 0, m, &cBinop_ix12FAmE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GxUm2qwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0Dis7dIs, 0, m, &cVar_0Dis7dIs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ix12FAmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_d21ssCRF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NzpIap32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ddK004mz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Wl0R3NdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_moLrtuen_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zoUdCNZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_NGR5to1k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RX250xWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_LjNxulA4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_moLrtuen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RX250xWo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LjNxulA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_zoUdCNZt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NGR5to1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2jmUOVqd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_tK517MUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KkD7xSWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MM6nexoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZaiQz2EP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_N6x23vPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lwTLeUUI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_wUcHYjhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rDiI1HRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Jwo37R3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_owuJMusS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_n0V3NO3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J1M4nSNz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JlY8nh9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SDwpNta5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_KZs3SSrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R9cenRjB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WmUSbVJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HwxicpPf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_9IfaK98A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0da6I5NF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vEE1Ir0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h51RqpoY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_HgH2LGcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SkrhpYjD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_sRU6uM8O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2nlg65Gm, 0, m, &cSlice_2nlg65Gm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_2nlg65Gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YPWCz53g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YPWCz53g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Tm1s5vAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YPWCz53g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YPWCz53g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7VCpA57F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_YDXE2MgZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ddyBTqBQ, 0, m, &cSlice_ddyBTqBQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8LFhGhTQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ddyBTqBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pbCxajWU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pbCxajWU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xyyOTJXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pbCxajWU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pbCxajWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kK3yICrs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_p5iqI9kd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PhmEj4OY, 0, m, &cSlice_PhmEj4OY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sRU6uM8O_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_PhmEj4OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n3SS8Ibs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n3SS8Ibs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8Z2CYF87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n3SS8Ibs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_n3SS8Ibs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XQlQgDH1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YE9egiLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aOt12cBd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aOt12cBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_aJSRaLYp_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_qBjxgGiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xhG4K0uz_sendMessage(_c, 0, m);
  cMsg_iiwTrS6F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_U25inKaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ncv1zqWi_sendMessage(_c, 0, m);
  cMsg_WrPxbqOr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aJSRaLYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0s12OFy1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0s12OFy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YbIHJRtQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9uSPYsu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YbIHJRtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EzoQqctf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V9uSPYsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vUnmwJIe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EzoQqctf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8UKCPMqJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vUnmwJIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lX4afXQn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lX4afXQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QwK8GjWo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8UKCPMqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qBjxgGiZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QwK8GjWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_U25inKaz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yzTZJeKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XId4Y920_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XId4Y920_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_DihXomNt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DihXomNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_F3wPWVML_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F3wPWVML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_INtMGn8p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kUXTZp0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_INtMGn8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8Oqpl0cS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kUXTZp0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tMtT8SIa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8Oqpl0cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tbEPOW22_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tMtT8SIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tS1iT04A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tS1iT04A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wC43Gu3R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wC43Gu3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zzmWZQM8_sendMessage(_c, 0, m);
  cMsg_q4xRIgNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tbEPOW22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HzkDqC0c_sendMessage(_c, 0, m);
  cMsg_fvw4Wq6Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0PsN834a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UCFVGUsv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UCFVGUsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5jdJKyta_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5NGJHLOv_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_l4VZk7Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vJ2jwFa6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NHAtjrba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hPl6tUlV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hPl6tUlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JGqGF1tB, HV_BINOP_DIVIDE, 1, m, &cBinop_JGqGF1tB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5jdJKyta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dqAnVQ7G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dqAnVQ7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Dj0dNoF8, m);
}

void Heavy_WSTD_DL3Y::cMsg_G4mnhSpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eSTBzgg9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eSTBzgg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0PsN834a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5NGJHLOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FckXArST, m);
}

void Heavy_WSTD_DL3Y::cBinop_vJ2jwFa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_OH7FGTKK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OH7FGTKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JGqGF1tB, HV_BINOP_DIVIDE, 0, m, &cBinop_JGqGF1tB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JGqGF1tB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G4mnhSpL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_v2LlTNMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lDlbnpaI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lDlbnpaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_q3Bgs0iM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rSB3eMMs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_o9ugZ9rR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_iK4iioPu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ikxKlCjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oKUeuEQz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oKUeuEQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DPUQj8gJ, HV_BINOP_DIVIDE, 1, m, &cBinop_DPUQj8gJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q3Bgs0iM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wEj7ib53_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wEj7ib53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eCiVjmuq, m);
}

void Heavy_WSTD_DL3Y::cMsg_p3gbqpPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ks6QkDSL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ks6QkDSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_v2LlTNMX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rSB3eMMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bb4GFQUg, m);
}

void Heavy_WSTD_DL3Y::cBinop_iK4iioPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_IWeTrmdU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IWeTrmdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DPUQj8gJ, HV_BINOP_DIVIDE, 0, m, &cBinop_DPUQj8gJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DPUQj8gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p3gbqpPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xPmnxjRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fnzisqHz, HV_BINOP_MULTIPLY, 0, m, &cBinop_fnzisqHz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C5ZTJkwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FLlkzZVm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_FLlkzZVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3VX2enHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fnzisqHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8XpJ6gik_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NREn9Y8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fnzisqHz, HV_BINOP_MULTIPLY, 1, m, &cBinop_fnzisqHz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3VX2enHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NREn9Y8M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8XpJ6gik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_I2Kh3r1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I2Kh3r1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_erpcNgh1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ax01LzD8, m);
}

void Heavy_WSTD_DL3Y::cBinop_erpcNgh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cPtZosMS, m);
}

void Heavy_WSTD_DL3Y::cVar_zXdmqJkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KHoDMfo0, HV_BINOP_MULTIPLY, 0, m, &cBinop_KHoDMfo0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RolXLF8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xp6RBs2A_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xp6RBs2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FbQ5AOcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KHoDMfo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Jxc0KG35_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0FOWYjny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KHoDMfo0, HV_BINOP_MULTIPLY, 1, m, &cBinop_KHoDMfo0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FbQ5AOcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0FOWYjny_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jxc0KG35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_l429U6wP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l429U6wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_swCM2iva_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eJaDQ4kW, m);
}

void Heavy_WSTD_DL3Y::cBinop_swCM2iva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JqN53mXS, m);
}

void Heavy_WSTD_DL3Y::sEnv_oPREYVrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fAbjRfR4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jb6p3Mc9_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_z3LByDyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_2tBgRToN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IWqPKunb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_xxfFwK8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hO6Sxijo, HV_BINOP_POW, 0, m, &cBinop_hO6Sxijo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hO6Sxijo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ifHsAHYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4p1bV7UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_QpXd1dyS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fAbjRfR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uZo5TrKj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jb6p3Mc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z3LByDyD, 0, m, &cIf_z3LByDyD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uZo5TrKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z3LByDyD, 1, m, &cIf_z3LByDyD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IWqPKunb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4p1bV7UW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2tBgRToN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_ifHsAHYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QpXd1dyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hO6Sxijo, HV_BINOP_POW, 1, m, &cBinop_hO6Sxijo_sendMessage);
  cMsg_xxfFwK8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gRKl002F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCvw8qfP, HV_BINOP_MULTIPLY, 0, m, &cBinop_WCvw8qfP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TAkrk2FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dNGigWnz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dNGigWnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_psAeaHdX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WCvw8qfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vRw063Ff_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_23ZxB8Wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCvw8qfP, HV_BINOP_MULTIPLY, 1, m, &cBinop_WCvw8qfP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_psAeaHdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_23ZxB8Wz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vRw063Ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YIx5MAQR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YIx5MAQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ft926vQB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7mHlP2Ya, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ft926vQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rhe2eoJH, m);
}

void Heavy_WSTD_DL3Y::cMsg_ifHsAHYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_te2QHlrv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_te2QHlrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UAkGPCfn, m);
}

void Heavy_WSTD_DL3Y::sEnv_LhHr4qYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KXTL4X7o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AxkisXxO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_WSDfejaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3Qy5VtWO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ItEjWYWn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JWSTCwvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bJKE6OlN, HV_BINOP_POW, 0, m, &cBinop_bJKE6OlN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bJKE6OlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZkPHO3Tm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_v9hMPYuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hQr2ScQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KXTL4X7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GuutjpRL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AxkisXxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WSDfejaA, 0, m, &cIf_WSDfejaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GuutjpRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WSDfejaA, 1, m, &cIf_WSDfejaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ItEjWYWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_v9hMPYuj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3Qy5VtWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_ZkPHO3Tm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hQr2ScQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bJKE6OlN, HV_BINOP_POW, 1, m, &cBinop_bJKE6OlN_sendMessage);
  cMsg_JWSTCwvV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_qIkhJdFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B0mQuqhA, HV_BINOP_MULTIPLY, 0, m, &cBinop_B0mQuqhA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_v9ob1OgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PK3SsR9X_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PK3SsR9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4fsTgTy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_B0mQuqhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rVK2vTnx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r61iL92Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B0mQuqhA, HV_BINOP_MULTIPLY, 1, m, &cBinop_B0mQuqhA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4fsTgTy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_r61iL92Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rVK2vTnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WZOhZVUp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WZOhZVUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_poH0LS1f_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MzY4EkUR, m);
}

void Heavy_WSTD_DL3Y::cBinop_poH0LS1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TJN5nFZ1, m);
}

void Heavy_WSTD_DL3Y::cMsg_ZkPHO3Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rYi5iQYW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rYi5iQYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_98VINtJS, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8LFhGhTQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DTRBVgXs, 0, m, &cSlice_DTRBVgXs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_p5iqI9kd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DTRBVgXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ksBBBANG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ksBBBANG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_rI76b9rE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ksBBBANG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ksBBBANG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AknuaiHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bQ1tCbRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xBNe4Bs7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xBNe4Bs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TtgqOQd5_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Db49bACo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Db49bACo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_A70xWnOx, 0, m, &cDelay_A70xWnOx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Db49bACo, 0, m, &cDelay_Db49bACo_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CYTQE1B0, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_A70xWnOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A70xWnOx, m);
  cMsg_oOtxKmmk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_B6Ll179s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_c446I697_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_KQA29fZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UsXcRCm3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_eoPEpddH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hdljcRTJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Db49bACo, 2, m, &cDelay_Db49bACo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pR5oQHd8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UsXcRCm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_eoPEpddH, 0, m, &hTable_eoPEpddH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TtgqOQd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_KQA29fZZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oOtxKmmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_eoPEpddH, 0, m, &hTable_eoPEpddH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pR5oQHd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Db49bACo, 0, m, &cDelay_Db49bACo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hdljcRTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_A70xWnOx, 2, m, &cDelay_A70xWnOx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_c446I697_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CYTQE1B0, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_cNSuZUQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GwhHp49n, HV_BINOP_SUBTRACT, 0, m, &cBinop_GwhHp49n_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KNPkIDhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UfYxwhEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UfYxwhEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nNVWRFhB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_N0tkwQMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iS73Hxgi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_qy1Yyw75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qy1Yyw75, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AfFf4PxP, 0, m, &cDelay_AfFf4PxP_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_WPcLVBhM, 0, m, &sTabread_WPcLVBhM_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_AfFf4PxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AfFf4PxP, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_WPcLVBhM, 0, m, &sTabread_WPcLVBhM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AfFf4PxP, 0, m, &cDelay_AfFf4PxP_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_WPcLVBhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IIgmnERw, HV_BINOP_SUBTRACT, 0, m, &cBinop_IIgmnERw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_5VubsKcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5JctRDPT, HV_BINOP_MAX, 0, m, &cBinop_5JctRDPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nNVWRFhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VubsKcw, HV_BINOP_MULTIPLY, 0, m, &cBinop_5VubsKcw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GwhHp49n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qvEuZUal_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_WPcLVBhM, 0, m, &sTabread_WPcLVBhM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2hJTOu1n_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JxYv6bhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IIgmnERw, HV_BINOP_SUBTRACT, 1, m, &cBinop_IIgmnERw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AfFf4PxP, 2, m, &cDelay_AfFf4PxP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iS73Hxgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JxYv6bhP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qvEuZUal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qy1Yyw75, 0, m, &cDelay_qy1Yyw75_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AfFf4PxP, 0, m, &cDelay_AfFf4PxP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DX6QVhzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_5JctRDPT, HV_BINOP_MAX, 1, m, &cBinop_5JctRDPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5JctRDPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GwhHp49n, HV_BINOP_SUBTRACT, 1, m, &cBinop_GwhHp49n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2hJTOu1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qy1Yyw75, 0, m, &cDelay_qy1Yyw75_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_znqhb5Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qy1Yyw75, 2, m, &cDelay_qy1Yyw75_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IIgmnERw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_znqhb5Rs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oK4JAGnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N0tkwQMR, 0, m, &cVar_N0tkwQMR_sendMessage);
  cMsg_KNPkIDhY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cNSuZUQ3, 0, m, &cTabhead_cNSuZUQ3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OFdU3UWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eVxEkMmW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_eVxEkMmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_crrY5xv8_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_6YCoTOad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6YCoTOad, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BSPyrPl5, 0, m, &cDelay_BSPyrPl5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6YCoTOad, 0, m, &cDelay_6YCoTOad_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rrxit976, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_BSPyrPl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BSPyrPl5, m);
  cMsg_MDFu8M01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Ys0tk5pT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_jrE0IeTK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Xgagnxpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p82PKaKx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_Cqyzl2Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1UeIqia5_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6YCoTOad, 2, m, &cDelay_6YCoTOad_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y224LG4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_p82PKaKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Cqyzl2Nl, 0, m, &hTable_Cqyzl2Nl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_crrY5xv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Xgagnxpb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MDFu8M01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Cqyzl2Nl, 0, m, &hTable_Cqyzl2Nl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y224LG4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6YCoTOad, 0, m, &cDelay_6YCoTOad_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1UeIqia5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BSPyrPl5, 2, m, &cDelay_BSPyrPl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jrE0IeTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rrxit976, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_OtwtNCH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VdheAb2B, HV_BINOP_SUBTRACT, 0, m, &cBinop_VdheAb2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Oma7Y3Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aZv7zJvF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_aZv7zJvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kWDKkU6Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uJzzydHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NjpEEM3E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_fGFATPfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fGFATPfC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uIRi5lfe, 0, m, &cDelay_uIRi5lfe_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1brIOGkA, 0, m, &sTabread_1brIOGkA_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_uIRi5lfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uIRi5lfe, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1brIOGkA, 0, m, &sTabread_1brIOGkA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uIRi5lfe, 0, m, &cDelay_uIRi5lfe_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_1brIOGkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PVepO5O2, HV_BINOP_SUBTRACT, 0, m, &cBinop_PVepO5O2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_YJfUIxIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4MHhzpuk, HV_BINOP_MAX, 0, m, &cBinop_4MHhzpuk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kWDKkU6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YJfUIxIy, HV_BINOP_MULTIPLY, 0, m, &cBinop_YJfUIxIy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VdheAb2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cnpc3HpX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1brIOGkA, 0, m, &sTabread_1brIOGkA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4nO5dpBq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vnPua6wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PVepO5O2, HV_BINOP_SUBTRACT, 1, m, &cBinop_PVepO5O2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uIRi5lfe, 2, m, &cDelay_uIRi5lfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NjpEEM3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vnPua6wr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cnpc3HpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fGFATPfC, 0, m, &cDelay_fGFATPfC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uIRi5lfe, 0, m, &cDelay_uIRi5lfe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4G0Uvefv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4MHhzpuk, HV_BINOP_MAX, 1, m, &cBinop_4MHhzpuk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4MHhzpuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VdheAb2B, HV_BINOP_SUBTRACT, 1, m, &cBinop_VdheAb2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4nO5dpBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fGFATPfC, 0, m, &cDelay_fGFATPfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q39UD8jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fGFATPfC, 2, m, &cDelay_fGFATPfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PVepO5O2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Q39UD8jd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_soZXrRlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uJzzydHj, 0, m, &cVar_uJzzydHj_sendMessage);
  cMsg_Oma7Y3Zf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OtwtNCH8, 0, m, &cTabhead_OtwtNCH8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xhG4K0uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sYD2Uyey, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ncv1zqWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rc23rZ59, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WrPxbqOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3rxDs3xy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iiwTrS6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q3oZm1lY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fvw4Wq6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X6SomIef, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zzmWZQM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4T3rMgH9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HzkDqC0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eoUFaBLt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_q4xRIgNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vrvoMgsf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GMeqbAgy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o6jhHI0x, 0, m, &cSlice_o6jhHI0x_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_o6jhHI0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_46SzmJ5m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_46SzmJ5m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_CbfpwLXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_46SzmJ5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_46SzmJ5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mJEBV4pf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5YyZwON2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JnfU408Q, 0, m, &cSlice_JnfU408Q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_M8I7c0D4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_JnfU408Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IXBMhRe8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IXBMhRe8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Y02uujw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IXBMhRe8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_IXBMhRe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ahN7HzQR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BkFBF5Uf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_55xfpnti, 0, m, &cSlice_55xfpnti_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GMeqbAgy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_55xfpnti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ohw7tQ6X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ohw7tQ6X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_f72vXSLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ohw7tQ6X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ohw7tQ6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1ZkOiKJK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hpkr1TlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gCAr9ifl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gCAr9ifl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_eQZwfbfn_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_X8H4SklN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IzY3YUpR_sendMessage(_c, 0, m);
  cMsg_76G5UdbK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_S5IH1tFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QcDoqBxv_sendMessage(_c, 0, m);
  cMsg_NnoHzVc7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eQZwfbfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3i2k9eTV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3i2k9eTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DhrBfkw1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2LfsBS0n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2LfsBS0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xr95chgO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DhrBfkw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TgrEaJ9l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TgrEaJ9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EbfKUHLW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xr95chgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ehx3pgb0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ehx3pgb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fa1aUWhQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EbfKUHLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_X8H4SklN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fa1aUWhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_S5IH1tFP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nqYFK04g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KmldwN7l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KmldwN7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3k0iCpME_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3k0iCpME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pfWDu0ue_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pfWDu0ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SKgObndv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cymUnWlU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SKgObndv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6ZgEOtBo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cymUnWlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V3BuRD0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6ZgEOtBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6f8WgTIG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V3BuRD0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GcacXSFc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GcacXSFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_81a7ZOVN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_81a7ZOVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DSQFTtlN_sendMessage(_c, 0, m);
  cMsg_SZYl7sRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6f8WgTIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GGxgDvKc_sendMessage(_c, 0, m);
  cMsg_6WII2UgI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wEyCLLlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VsfnfSLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VsfnfSLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YGdFpaNH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_crOK86E2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ciroSFWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vav1Gwbk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FPfkIvd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_74iC5Ndk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_74iC5Ndk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6rXHT7KW, HV_BINOP_DIVIDE, 1, m, &cBinop_6rXHT7KW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YGdFpaNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Up9dt6Zf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Up9dt6Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_z33QE8Q7, m);
}

void Heavy_WSTD_DL3Y::cMsg_GiyzSeTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SJyuP6cK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SJyuP6cK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_wEyCLLlL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_crOK86E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WUr6BnDG, m);
}

void Heavy_WSTD_DL3Y::cBinop_vav1Gwbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_7nryxYbn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7nryxYbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6rXHT7KW, HV_BINOP_DIVIDE, 0, m, &cBinop_6rXHT7KW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6rXHT7KW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GiyzSeTd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_El3fmuGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hDNBXX4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hDNBXX4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8y3e4luK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RpkDiFL8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_85MXhTsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_gJs0joEf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dYAxg481_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7OEqzPkm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7OEqzPkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_auJjgDuR, HV_BINOP_DIVIDE, 1, m, &cBinop_auJjgDuR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8y3e4luK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t2YbY4vx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t2YbY4vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FG2fuiGx, m);
}

void Heavy_WSTD_DL3Y::cMsg_tpAkwx2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yLIUJPIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yLIUJPIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_El3fmuGE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RpkDiFL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nNTUL8PY, m);
}

void Heavy_WSTD_DL3Y::cBinop_gJs0joEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Nemo4uzI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nemo4uzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_auJjgDuR, HV_BINOP_DIVIDE, 0, m, &cBinop_auJjgDuR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_auJjgDuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tpAkwx2w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6mKWfkcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tqHSJGON, HV_BINOP_MULTIPLY, 0, m, &cBinop_tqHSJGON_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_p96WOVJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_792gJYMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_792gJYMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dw1QPksP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tqHSJGON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0L6Z6uHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rjUoZbnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tqHSJGON, HV_BINOP_MULTIPLY, 1, m, &cBinop_tqHSJGON_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Dw1QPksP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rjUoZbnc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0L6Z6uHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_i4g2mvJL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i4g2mvJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_v5chq43Q_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YQdUPxPp, m);
}

void Heavy_WSTD_DL3Y::cBinop_v5chq43Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wNHqX7AG, m);
}

void Heavy_WSTD_DL3Y::cVar_200mAezC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bIEaoVzm, HV_BINOP_MULTIPLY, 0, m, &cBinop_bIEaoVzm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q9CUzMPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_818e2cz2_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_818e2cz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hle35bDM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bIEaoVzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZBo0tjlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y935XgCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bIEaoVzm, HV_BINOP_MULTIPLY, 1, m, &cBinop_bIEaoVzm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hle35bDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Y935XgCu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZBo0tjlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_splDWiIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_splDWiIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0iQQOS8L_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7SlQm7NT, m);
}

void Heavy_WSTD_DL3Y::cBinop_0iQQOS8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ln00Kr2x, m);
}

void Heavy_WSTD_DL3Y::sEnv_nE6lbdBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5csIcaHo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yXVNAvaS_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_72eh65wV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Kvz5UfhK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_dfLToTn4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Lnj1g0vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tcuZUWat, HV_BINOP_POW, 0, m, &cBinop_tcuZUWat_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tcuZUWat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LQ5wHW5y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KCED8w8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GbA00Kli_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5csIcaHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ltq5GpAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yXVNAvaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_72eh65wV, 0, m, &cIf_72eh65wV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ltq5GpAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_72eh65wV, 1, m, &cIf_72eh65wV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dfLToTn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_KCED8w8p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Kvz5UfhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_LQ5wHW5y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GbA00Kli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tcuZUWat, HV_BINOP_POW, 1, m, &cBinop_tcuZUWat_sendMessage);
  cMsg_Lnj1g0vz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xc8rPMR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9BRro1C7, HV_BINOP_MULTIPLY, 0, m, &cBinop_9BRro1C7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8SQ7AJcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xFiQwzCT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xFiQwzCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ffa8xJuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9BRro1C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IHhS0i3i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SyRDRmdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9BRro1C7, HV_BINOP_MULTIPLY, 1, m, &cBinop_9BRro1C7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ffa8xJuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SyRDRmdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IHhS0i3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0I8IyrVY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0I8IyrVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XekNVjnJ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_opO13Pww, m);
}

void Heavy_WSTD_DL3Y::cBinop_XekNVjnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HQghlH9Y, m);
}

void Heavy_WSTD_DL3Y::cMsg_LQ5wHW5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AMOf7wHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AMOf7wHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IziHBJrK, m);
}

void Heavy_WSTD_DL3Y::sEnv_7QKfknxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8PqVGPG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DeEBHITd_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_myxXX98C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CZ6j6sMZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_d4MEUalr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_sc4mJwsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wu7yQTRl, HV_BINOP_POW, 0, m, &cBinop_wu7yQTRl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wu7yQTRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zH7xSx9E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VuRnTU0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tuuU3nau_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DeEBHITd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_myxXX98C, 0, m, &cIf_myxXX98C_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q8PqVGPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mCA0QRQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mCA0QRQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_myxXX98C, 1, m, &cIf_myxXX98C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d4MEUalr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VuRnTU0E_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CZ6j6sMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_zH7xSx9E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tuuU3nau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wu7yQTRl, HV_BINOP_POW, 1, m, &cBinop_wu7yQTRl_sendMessage);
  cMsg_sc4mJwsm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_PvqehwdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqfV5OLs, HV_BINOP_MULTIPLY, 0, m, &cBinop_JqfV5OLs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xo7leFgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_diMJAY4j_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_diMJAY4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hxdHsTEk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JqfV5OLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Yg45txAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MKwqihLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqfV5OLs, HV_BINOP_MULTIPLY, 1, m, &cBinop_JqfV5OLs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hxdHsTEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MKwqihLQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yg45txAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_axCMjKtR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_axCMjKtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tiw48d5P_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_P5qE9dVf, m);
}

void Heavy_WSTD_DL3Y::cBinop_tiw48d5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eN0RH2FW, m);
}

void Heavy_WSTD_DL3Y::cMsg_zH7xSx9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_izFfNAos_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_izFfNAos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_e8WCIrK3, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_M8I7c0D4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_83ISb95I, 0, m, &cSlice_83ISb95I_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BkFBF5Uf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_83ISb95I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FWgWMb3X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FWgWMb3X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GAEOp89w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FWgWMb3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_FWgWMb3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qi5ka4dG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_A6LhcTob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kPOt8UIs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kPOt8UIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rI4TggtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_saSRNedJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_saSRNedJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbcBQoVu, 0, m, &cDelay_bbcBQoVu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_saSRNedJ, 0, m, &cDelay_saSRNedJ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_X1aicy1o, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_bbcBQoVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bbcBQoVu, m);
  cMsg_7EcNTGDQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_g617ggdN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_oDPgyWXZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_rHQLTgkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TpAzmoK3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_14y3n6lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DsmObo69_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_saSRNedJ, 2, m, &cDelay_saSRNedJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sbQRRhGV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TpAzmoK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_14y3n6lS, 0, m, &hTable_14y3n6lS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rI4TggtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_rHQLTgkI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7EcNTGDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_14y3n6lS, 0, m, &hTable_14y3n6lS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sbQRRhGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_saSRNedJ, 0, m, &cDelay_saSRNedJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DsmObo69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bbcBQoVu, 2, m, &cDelay_bbcBQoVu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oDPgyWXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_X1aicy1o, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_IiVFJpOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vYKbaIVi, HV_BINOP_SUBTRACT, 0, m, &cBinop_vYKbaIVi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gcBVkdGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fUT9T1H0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fUT9T1H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3oZsD0KI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ooHG4pu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_emVXc06F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_UyRd2k8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UyRd2k8I, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsQtnHLV, 0, m, &cDelay_MsQtnHLV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YhFKF7eX, 0, m, &sTabread_YhFKF7eX_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_MsQtnHLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MsQtnHLV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YhFKF7eX, 0, m, &sTabread_YhFKF7eX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsQtnHLV, 0, m, &cDelay_MsQtnHLV_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_YhFKF7eX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wd7ZGKBJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_wd7ZGKBJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_pE4K1zTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3mjEw0Em, HV_BINOP_MAX, 0, m, &cBinop_3mjEw0Em_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3oZsD0KI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pE4K1zTa, HV_BINOP_MULTIPLY, 0, m, &cBinop_pE4K1zTa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vYKbaIVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5XDzOZlJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YhFKF7eX, 0, m, &sTabread_YhFKF7eX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iPLU9r1R_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_DyitqCeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wd7ZGKBJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_wd7ZGKBJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsQtnHLV, 2, m, &cDelay_MsQtnHLV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_emVXc06F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DyitqCeb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5XDzOZlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UyRd2k8I, 0, m, &cDelay_UyRd2k8I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsQtnHLV, 0, m, &cDelay_MsQtnHLV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dPzNQbaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_3mjEw0Em, HV_BINOP_MAX, 1, m, &cBinop_3mjEw0Em_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3mjEw0Em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vYKbaIVi, HV_BINOP_SUBTRACT, 1, m, &cBinop_vYKbaIVi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iPLU9r1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UyRd2k8I, 0, m, &cDelay_UyRd2k8I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OXiAUkms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UyRd2k8I, 2, m, &cDelay_UyRd2k8I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wd7ZGKBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OXiAUkms_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hfVpMFXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ooHG4pu4, 0, m, &cVar_ooHG4pu4_sendMessage);
  cMsg_gcBVkdGp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IiVFJpOc, 0, m, &cTabhead_IiVFJpOc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qiAvcrKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LpA19GrU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LpA19GrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qAL8SQzD_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_XG3xF2zZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XG3xF2zZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dMdFq9sy, 0, m, &cDelay_dMdFq9sy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XG3xF2zZ, 0, m, &cDelay_XG3xF2zZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hpQ3UYZp, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_dMdFq9sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dMdFq9sy, m);
  cMsg_gXe1p49n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_VRYl2qMi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_9O5A6AZ2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_1fqXmK1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_75aCy91Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_6v0TUFb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JCH4lhqX_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XG3xF2zZ, 2, m, &cDelay_XG3xF2zZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_izbhcgiL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_75aCy91Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_6v0TUFb4, 0, m, &hTable_6v0TUFb4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qAL8SQzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_1fqXmK1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gXe1p49n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_6v0TUFb4, 0, m, &hTable_6v0TUFb4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_izbhcgiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XG3xF2zZ, 0, m, &cDelay_XG3xF2zZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JCH4lhqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dMdFq9sy, 2, m, &cDelay_dMdFq9sy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9O5A6AZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hpQ3UYZp, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_ha4NXJFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_veHCedhm, HV_BINOP_SUBTRACT, 0, m, &cBinop_veHCedhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NhDPrTUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JZT94adY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JZT94adY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Pj6x58Uw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xr0amzKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y4zgPDSp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Xjybfjba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xjybfjba, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8MDbedaw, 0, m, &cDelay_8MDbedaw_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yYfm8epR, 0, m, &sTabread_yYfm8epR_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_8MDbedaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8MDbedaw, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yYfm8epR, 0, m, &sTabread_yYfm8epR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8MDbedaw, 0, m, &cDelay_8MDbedaw_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_yYfm8epR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_b5zc4uXv, HV_BINOP_SUBTRACT, 0, m, &cBinop_b5zc4uXv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_bHSmIMwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyHX0Jrc, HV_BINOP_MAX, 0, m, &cBinop_UyHX0Jrc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pj6x58Uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHSmIMwS, HV_BINOP_MULTIPLY, 0, m, &cBinop_bHSmIMwS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_veHCedhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_13c7HEh3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_yYfm8epR, 0, m, &sTabread_yYfm8epR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u7yeJXac_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zRu02LJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b5zc4uXv, HV_BINOP_SUBTRACT, 1, m, &cBinop_b5zc4uXv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8MDbedaw, 2, m, &cDelay_8MDbedaw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_y4zgPDSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zRu02LJx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_13c7HEh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xjybfjba, 0, m, &cDelay_Xjybfjba_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8MDbedaw, 0, m, &cDelay_8MDbedaw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hZAx4uRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyHX0Jrc, HV_BINOP_MAX, 1, m, &cBinop_UyHX0Jrc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UyHX0Jrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_veHCedhm, HV_BINOP_SUBTRACT, 1, m, &cBinop_veHCedhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_u7yeJXac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xjybfjba, 0, m, &cDelay_Xjybfjba_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wmo7emZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xjybfjba, 2, m, &cDelay_Xjybfjba_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b5zc4uXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wmo7emZ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JWnSskJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xr0amzKT, 0, m, &cVar_xr0amzKT_sendMessage);
  cMsg_NhDPrTUR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ha4NXJFC, 0, m, &cTabhead_ha4NXJFC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IzY3YUpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GZcbPNo3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QcDoqBxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_451ToWYh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NnoHzVc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GH1DHAYX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_76G5UdbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vAkhrvc9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6WII2UgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fAiGLOpp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DSQFTtlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IVwkv12O, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GGxgDvKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nkGOeCMc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SZYl7sRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jM0z6W93, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gm0S64l9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3EdSHWvE, 0, m, &cSlice_3EdSHWvE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3EdSHWvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3RqpDXcB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3RqpDXcB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_0JRyog2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3RqpDXcB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_3RqpDXcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QIaTxKyR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_TNhRL3B1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cFOeZCo5, 0, m, &cSlice_cFOeZCo5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4o8FZ5Q7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_cFOeZCo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J87ucNC9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J87ucNC9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Sf9cDpV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J87ucNC9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_J87ucNC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wPqtdMjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4v3O45Uh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B9jhZON6, 0, m, &cSlice_B9jhZON6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gm0S64l9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_B9jhZON6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D73cBw3b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D73cBw3b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_J7XYPB7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D73cBw3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_D73cBw3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zyja7CDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Xmgrmi5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3MWm15vh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3MWm15vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_WnLaFlcA_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_AOMxBGW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vI9aNGqd_sendMessage(_c, 0, m);
  cMsg_NjlInau3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_PdfpDhL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mrWMEqvQ_sendMessage(_c, 0, m);
  cMsg_kwuXJrVM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WnLaFlcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Kf2BT7Qs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kf2BT7Qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jRxVX4Wi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qfyFI96Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qfyFI96Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fElt2OJe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jRxVX4Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MhWGKwzs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MhWGKwzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9ICFf5NY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fElt2OJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SctIK26x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SctIK26x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_E4J7qjJD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ICFf5NY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_AOMxBGW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E4J7qjJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_PdfpDhL7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QYiFzmZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3As0pI9Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3As0pI9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_UZbewxdU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UZbewxdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ddymjjxy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ddymjjxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uZjavm23_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BGBg4ySA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BGBg4ySA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mWd5jlt1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uZjavm23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sSFTIowK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sSFTIowK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0KHPgc5M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mWd5jlt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6wfq7QSG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6wfq7QSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0W5vTTLO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0W5vTTLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4SnQsY5g_sendMessage(_c, 0, m);
  cMsg_yGjJeIWY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0KHPgc5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GqTxJMPD_sendMessage(_c, 0, m);
  cMsg_l44li13w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bEA5ylwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_o0dq7oQa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o0dq7oQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8MTADEEt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4QNBpSuT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HyOoQTG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Vq9yunSd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ls77NkA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uG0RvNXR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uG0RvNXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rKls0qJP, HV_BINOP_DIVIDE, 1, m, &cBinop_rKls0qJP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8MTADEEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MhNTbd30_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MhNTbd30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lZJ2qzKt, m);
}

void Heavy_WSTD_DL3Y::cMsg_Zr85otz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YDUcDex9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YDUcDex9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bEA5ylwg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4QNBpSuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dh5GWp7q, m);
}

void Heavy_WSTD_DL3Y::cBinop_Vq9yunSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_dgkLVzUD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dgkLVzUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rKls0qJP, HV_BINOP_DIVIDE, 0, m, &cBinop_rKls0qJP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rKls0qJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zr85otz4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LpeiQSRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2eXNcyWW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2eXNcyWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ISSCsfT7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yrVU6LAU_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_83Aqljyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_cSs8QTT2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0fIR0u7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CE6FYBUo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CE6FYBUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eh04Qdg3, HV_BINOP_DIVIDE, 1, m, &cBinop_eh04Qdg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ISSCsfT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Fc4oIPEE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Fc4oIPEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_W4fyXXpU, m);
}

void Heavy_WSTD_DL3Y::cMsg_QDPYHVy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ArSMgFXq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ArSMgFXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LpeiQSRp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yrVU6LAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_X4fN5Y2L, m);
}

void Heavy_WSTD_DL3Y::cBinop_cSs8QTT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_IEcwecnf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IEcwecnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eh04Qdg3, HV_BINOP_DIVIDE, 0, m, &cBinop_eh04Qdg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eh04Qdg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QDPYHVy3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_yqMxRPMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TfKjKV6c, HV_BINOP_MULTIPLY, 0, m, &cBinop_TfKjKV6c_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_au0ELK8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1uMPuSvR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1uMPuSvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fc3UXmhk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TfKjKV6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JOkhOFLr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TL3wRKCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TfKjKV6c, HV_BINOP_MULTIPLY, 1, m, &cBinop_TfKjKV6c_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fc3UXmhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TL3wRKCv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JOkhOFLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_USsiYhKE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_USsiYhKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_HO6cOKdy_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nrESerZN, m);
}

void Heavy_WSTD_DL3Y::cBinop_HO6cOKdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_S3OKdy2M, m);
}

void Heavy_WSTD_DL3Y::cVar_oIozDihk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIGuyCFD, HV_BINOP_MULTIPLY, 0, m, &cBinop_NIGuyCFD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SEBW9tX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_x9kSEoAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_x9kSEoAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XttXMmTI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NIGuyCFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4RivP4lO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FXlzeovZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIGuyCFD, HV_BINOP_MULTIPLY, 1, m, &cBinop_NIGuyCFD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XttXMmTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FXlzeovZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4RivP4lO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WXRlXLhg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WXRlXLhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1BBv4EQK_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pMFSKvRq, m);
}

void Heavy_WSTD_DL3Y::cBinop_1BBv4EQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ypNloANd, m);
}

void Heavy_WSTD_DL3Y::sEnv_8NFZ0dcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hrrrNCja_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3v6DftTk_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2nnnOLdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JW1SjSVU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aWctdeGr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_nM3YdppF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MhpiftwI, HV_BINOP_POW, 0, m, &cBinop_MhpiftwI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MhpiftwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vNtsZuE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qOod3mdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_FtGiTkMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3v6DftTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nnnOLdY, 0, m, &cIf_2nnnOLdY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hrrrNCja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kh99KmUp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kh99KmUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nnnOLdY, 1, m, &cIf_2nnnOLdY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aWctdeGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qOod3mdk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JW1SjSVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_vNtsZuE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FtGiTkMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MhpiftwI, HV_BINOP_POW, 1, m, &cBinop_MhpiftwI_sendMessage);
  cMsg_nM3YdppF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LF0cb9pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ofuLKfuE, HV_BINOP_MULTIPLY, 0, m, &cBinop_ofuLKfuE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DsIAAQ7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AUXhm5N7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_AUXhm5N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8H7fbaR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ofuLKfuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RsB09Ehq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AmXpcHVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ofuLKfuE, HV_BINOP_MULTIPLY, 1, m, &cBinop_ofuLKfuE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q8H7fbaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AmXpcHVD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RsB09Ehq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UFqdSOCq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UFqdSOCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LrhBjv4Y_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BftbGXW0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LrhBjv4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HnTmPoHQ, m);
}

void Heavy_WSTD_DL3Y::cMsg_vNtsZuE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qBJI6gs1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qBJI6gs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rIHauaqU, m);
}

void Heavy_WSTD_DL3Y::sEnv_zq3ROpKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gS7qBwlQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xQw0WYAZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_GrKm3dwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_gvwnEvkp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ClsCB3H1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_7TgMeh3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RRKoGlmU, HV_BINOP_POW, 0, m, &cBinop_RRKoGlmU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RRKoGlmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n0k86Opv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iR76RVox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_94dHf51q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xQw0WYAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GrKm3dwN, 0, m, &cIf_GrKm3dwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gS7qBwlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UNwjcgfM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UNwjcgfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GrKm3dwN, 1, m, &cIf_GrKm3dwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ClsCB3H1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_iR76RVox_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gvwnEvkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_n0k86Opv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_94dHf51q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RRKoGlmU, HV_BINOP_POW, 1, m, &cBinop_RRKoGlmU_sendMessage);
  cMsg_7TgMeh3G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BupxHVXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pLrGngd, HV_BINOP_MULTIPLY, 0, m, &cBinop_4pLrGngd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dRDgOLoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uaMP4YZh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uaMP4YZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dtChJNbn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4pLrGngd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jCPiuw3r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fFUaKqJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pLrGngd, HV_BINOP_MULTIPLY, 1, m, &cBinop_4pLrGngd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dtChJNbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fFUaKqJd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jCPiuw3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Sm7ZG9yK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sm7ZG9yK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UMcbhCyt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GYe8vt10, m);
}

void Heavy_WSTD_DL3Y::cBinop_UMcbhCyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5zY9b8d7, m);
}

void Heavy_WSTD_DL3Y::cMsg_n0k86Opv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p4IAW32G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p4IAW32G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_C9mlg7bP, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4o8FZ5Q7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k5KG8Dfm, 0, m, &cSlice_k5KG8Dfm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4v3O45Uh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_k5KG8Dfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_C4JOyL2U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_C4JOyL2U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xdQtQVLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C4JOyL2U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_C4JOyL2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_71f3sNBW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_7HhTrDMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y4mTYBvQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Y4mTYBvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_g4RKPKbr_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_gwv6jczt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gwv6jczt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EAQZemfZ, 0, m, &cDelay_EAQZemfZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwv6jczt, 0, m, &cDelay_gwv6jczt_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xoc7icvo, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_EAQZemfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EAQZemfZ, m);
  cMsg_3Sxsk7Bc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qrQdZxlb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_daH8wcdd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_2qOtJMHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WdpvXw4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_bLZK9s7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wHguvUhh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwv6jczt, 2, m, &cDelay_gwv6jczt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nsrr0xbM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WdpvXw4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bLZK9s7Q, 0, m, &hTable_bLZK9s7Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g4RKPKbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_2qOtJMHF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3Sxsk7Bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bLZK9s7Q, 0, m, &hTable_bLZK9s7Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nsrr0xbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gwv6jczt, 0, m, &cDelay_gwv6jczt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wHguvUhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_EAQZemfZ, 2, m, &cDelay_EAQZemfZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_daH8wcdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xoc7icvo, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_kfkfjS5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bf5ik0Ah, HV_BINOP_SUBTRACT, 0, m, &cBinop_bf5ik0Ah_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b59igsKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bpkb5xpG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bpkb5xpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tuBdQubK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_iMMUUyyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5vZ91F4x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_MNypWIWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MNypWIWy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6U7fWdW, 0, m, &cDelay_a6U7fWdW_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_E62LNqw6, 0, m, &sTabread_E62LNqw6_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_a6U7fWdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a6U7fWdW, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_E62LNqw6, 0, m, &sTabread_E62LNqw6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6U7fWdW, 0, m, &cDelay_a6U7fWdW_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_E62LNqw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5gWQHRif, HV_BINOP_SUBTRACT, 0, m, &cBinop_5gWQHRif_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_h0Op2nec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CRaFRaio, HV_BINOP_MAX, 0, m, &cBinop_CRaFRaio_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tuBdQubK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h0Op2nec, HV_BINOP_MULTIPLY, 0, m, &cBinop_h0Op2nec_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bf5ik0Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sVYDLkff_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_E62LNqw6, 0, m, &sTabread_E62LNqw6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBf37zJc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cTBSqY3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5gWQHRif, HV_BINOP_SUBTRACT, 1, m, &cBinop_5gWQHRif_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6U7fWdW, 2, m, &cDelay_a6U7fWdW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5vZ91F4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cTBSqY3C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sVYDLkff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MNypWIWy, 0, m, &cDelay_MNypWIWy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6U7fWdW, 0, m, &cDelay_a6U7fWdW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_URmEsHLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_CRaFRaio, HV_BINOP_MAX, 1, m, &cBinop_CRaFRaio_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CRaFRaio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bf5ik0Ah, HV_BINOP_SUBTRACT, 1, m, &cBinop_bf5ik0Ah_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZBf37zJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MNypWIWy, 0, m, &cDelay_MNypWIWy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HaRpePBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MNypWIWy, 2, m, &cDelay_MNypWIWy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5gWQHRif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HaRpePBl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zMLS7Eku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iMMUUyyV, 0, m, &cVar_iMMUUyyV_sendMessage);
  cMsg_b59igsKi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kfkfjS5G, 0, m, &cTabhead_kfkfjS5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nUelrcBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f2VgKbJx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_f2VgKbJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_MJLb46ns_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Dkc7wLSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Dkc7wLSw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FPMau9th, 0, m, &cDelay_FPMau9th_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dkc7wLSw, 0, m, &cDelay_Dkc7wLSw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SanbvW7K, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_FPMau9th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FPMau9th, m);
  cMsg_rEZzM9W5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zZcQL1r7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_K1wUuQtf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Mlsg9o7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QPav2sWX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_wQW2h6MV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4PL5mn8a_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dkc7wLSw, 2, m, &cDelay_Dkc7wLSw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jbcYYlHo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QPav2sWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_wQW2h6MV, 0, m, &hTable_wQW2h6MV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MJLb46ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Mlsg9o7p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rEZzM9W5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_wQW2h6MV, 0, m, &hTable_wQW2h6MV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jbcYYlHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dkc7wLSw, 0, m, &cDelay_Dkc7wLSw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4PL5mn8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_FPMau9th, 2, m, &cDelay_FPMau9th_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_K1wUuQtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SanbvW7K, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_IMZ4GTPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a2vZPkr5, HV_BINOP_SUBTRACT, 0, m, &cBinop_a2vZPkr5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q26rKc62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EnbJgDET_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EnbJgDET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tm07097R_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CttQjvSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tRfRTzLD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_wn5rbseH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wn5rbseH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bghc1LeD, 0, m, &cDelay_Bghc1LeD_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pj97Vfhv, 0, m, &sTabread_pj97Vfhv_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Bghc1LeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bghc1LeD, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pj97Vfhv, 0, m, &sTabread_pj97Vfhv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bghc1LeD, 0, m, &cDelay_Bghc1LeD_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_pj97Vfhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_kpEEfQi4, HV_BINOP_SUBTRACT, 0, m, &cBinop_kpEEfQi4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_VhCdQTQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gu6t0zMO, HV_BINOP_MAX, 0, m, &cBinop_Gu6t0zMO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tm07097R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VhCdQTQM, HV_BINOP_MULTIPLY, 0, m, &cBinop_VhCdQTQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a2vZPkr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2oSnGuQE_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pj97Vfhv, 0, m, &sTabread_pj97Vfhv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t2vUS5L0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bAXlrerD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpEEfQi4, HV_BINOP_SUBTRACT, 1, m, &cBinop_kpEEfQi4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bghc1LeD, 2, m, &cDelay_Bghc1LeD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tRfRTzLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bAXlrerD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2oSnGuQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wn5rbseH, 0, m, &cDelay_wn5rbseH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bghc1LeD, 0, m, &cDelay_Bghc1LeD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sQrVjwsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gu6t0zMO, HV_BINOP_MAX, 1, m, &cBinop_Gu6t0zMO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gu6t0zMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a2vZPkr5, HV_BINOP_SUBTRACT, 1, m, &cBinop_a2vZPkr5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t2vUS5L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wn5rbseH, 0, m, &cDelay_wn5rbseH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a55YzUr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wn5rbseH, 2, m, &cDelay_wn5rbseH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kpEEfQi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_a55YzUr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QD0JWKjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CttQjvSn, 0, m, &cVar_CttQjvSn_sendMessage);
  cMsg_Q26rKc62_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IMZ4GTPp, 0, m, &cTabhead_IMZ4GTPp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vI9aNGqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hglLjnnF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mrWMEqvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kq0aZiNG, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kwuXJrVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FnvMwhTf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NjlInau3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hvgOBvy7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_l44li13w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2D69JTTP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4SnQsY5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_POOmXL08, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GqTxJMPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9HSftv9E, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yGjJeIWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CM1mrbNv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_Shlzu8rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T5LIxUTl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XTAfrOS2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YQL9Ft6H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T5LIxUTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Shlzu8rs, 1, m, &cVar_Shlzu8rs_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_02423VRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_MM6nexoa, 0, m, &cVar_MM6nexoa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_CBB6tHb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_MM6nexoa, 0, m, &cVar_MM6nexoa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_eatG82sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CBB6tHb8, 0, m, &cIf_CBB6tHb8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Fw2Nui99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_02423VRz, 0, m, &cIf_02423VRz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_W9JWYsQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XYBNYwRf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TBZWxdBa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cucSzniA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XYBNYwRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W9JWYsQr, 1, m, &cVar_W9JWYsQr_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_AnOPITcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_n0V3NO3C, 0, m, &cVar_n0V3NO3C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_ZPl7FYg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_n0V3NO3C, 0, m, &cVar_n0V3NO3C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_fcIUli0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZPl7FYg3, 0, m, &cIf_ZPl7FYg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Jqw3Fv8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AnOPITcH, 0, m, &cIf_AnOPITcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_e44EFCpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yw7PJ8Pl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IdfJyLsJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_01uGa5w5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yw7PJ8Pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e44EFCpz, 1, m, &cVar_e44EFCpz_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_fjMAGoob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9IfaK98A, 0, m, &cVar_9IfaK98A_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_oJgqKzrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9IfaK98A, 0, m, &cVar_9IfaK98A_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6Iv9SVuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oJgqKzrj, 0, m, &cIf_oJgqKzrj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bhi1km0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fjMAGoob, 0, m, &cIf_fjMAGoob_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ViVKAXKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6PAQ8NN6, HV_BINOP_DIVIDE, 0, m, &cBinop_6PAQ8NN6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7S3ffZzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nBkHbW7V, HV_BINOP_MULTIPLY, 1, m, &cBinop_nBkHbW7V_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_YJeF0m5h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gI2k39Wv, 0, m, &cSlice_gI2k39Wv_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OBs5IKqH, 0, m, &cSlice_OBs5IKqH_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nsbcbmKb_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kzhlUZSb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gI2k39Wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_paOalqdM, 0, m, &cVar_paOalqdM_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_paOalqdM, 0, m, &cVar_paOalqdM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_OBs5IKqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_vPXRXlNT, HV_BINOP_NEQ, 1, m, &cBinop_vPXRXlNT_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_paOalqdM, 1, m, &cVar_paOalqdM_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_vPXRXlNT, HV_BINOP_NEQ, 1, m, &cBinop_vPXRXlNT_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_paOalqdM, 1, m, &cVar_paOalqdM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_paOalqdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_4hNNao9s_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_UNli2rWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9fiiERMj_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bmp7V6en_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_bmp7V6en_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_paOalqdM, 0, m, &cVar_paOalqdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9fiiERMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vPXRXlNT, HV_BINOP_NEQ, 1, m, &cBinop_vPXRXlNT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vPXRXlNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UNli2rWo, 1, m, &cIf_UNli2rWo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kzhlUZSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UNli2rWo, 0, m, &cIf_UNli2rWo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nsbcbmKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vPXRXlNT, HV_BINOP_NEQ, 0, m, &cBinop_vPXRXlNT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Wtg2SQfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1w7a0tux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zkqjb348_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LvEEBHel_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DbLy8FAk_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aGPGmLmD_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mubKm2Kk_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v5jfV12q_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kCU30bcV_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UnDxmiZv_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A0Aakhji_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FDgRHmnq_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dsO9dRZt_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M3ZrFd9x_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cYBWckgb_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eAYjN9UI_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uE5zDLJ3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_DbLy8FAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ubmKTOSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aGPGmLmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cCQoTUVO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mubKm2Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UPa3TEpl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_v5jfV12q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6V0e9GVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kCU30bcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mDux9m3P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UnDxmiZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ikjMrpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_A0Aakhji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_32p8txAt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FDgRHmnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T6bYQeq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dsO9dRZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RNS3Nu0Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_M3ZrFd9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0N3i7CoB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cYBWckgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jVGSexBw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eAYjN9UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UAXp3fxk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uE5zDLJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eRMfCWUo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6PAQ8NN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nBkHbW7V, HV_BINOP_MULTIPLY, 0, m, &cBinop_nBkHbW7V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nBkHbW7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YJeF0m5h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_1w7a0tux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6PAQ8NN6, HV_BINOP_DIVIDE, 1, m, &cBinop_6PAQ8NN6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Zkqjb348_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ViVKAXKq, 0, m, &cVar_ViVKAXKq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7S3ffZzI, 0, m, &cVar_7S3ffZzI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yeHItbqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7S3ffZzI, 0, m, &cVar_7S3ffZzI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8HcpjGt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ViVKAXKq, 0, m, &cVar_ViVKAXKq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ubmKTOSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cCQoTUVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UPa3TEpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6V0e9GVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mDux9m3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8ikjMrpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_32p8txAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T6bYQeq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RNS3Nu0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0N3i7CoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jVGSexBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UAXp3fxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eRMfCWUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yeHItbqY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8HcpjGt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8OPjnpD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nOqSRuta, HV_BINOP_DIVIDE, 0, m, &cBinop_nOqSRuta_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ca0mIoIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nuupajjK, HV_BINOP_MULTIPLY, 1, m, &cBinop_nuupajjK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iH40phNk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xMIBLODs, 0, m, &cSlice_xMIBLODs_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P1s7pyjA, 0, m, &cSlice_P1s7pyjA_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XEKSmJRm_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KbexDFjZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_xMIBLODs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_X0T5QCmg, 0, m, &cVar_X0T5QCmg_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_X0T5QCmg, 0, m, &cVar_X0T5QCmg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_P1s7pyjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DNxcND16, HV_BINOP_NEQ, 1, m, &cBinop_DNxcND16_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_X0T5QCmg, 1, m, &cVar_X0T5QCmg_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_DNxcND16, HV_BINOP_NEQ, 1, m, &cBinop_DNxcND16_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_X0T5QCmg, 1, m, &cVar_X0T5QCmg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_X0T5QCmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_4lrpMb4l_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kx3TFioN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2u7tOnBM_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Got9FRuL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_Got9FRuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X0T5QCmg, 0, m, &cVar_X0T5QCmg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2u7tOnBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNxcND16, HV_BINOP_NEQ, 1, m, &cBinop_DNxcND16_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DNxcND16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kx3TFioN, 1, m, &cIf_kx3TFioN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KbexDFjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kx3TFioN, 0, m, &cIf_kx3TFioN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XEKSmJRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DNxcND16, HV_BINOP_NEQ, 0, m, &cBinop_DNxcND16_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rcXfBBx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S29LtLIi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x4CiY37p_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_9sqPQl8B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x3CzlFuK_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fd87xuVD_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sUE0wkUt_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qPdd72o1_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_co6oyDeG_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MgR2uAQ8_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G4T8Pr9C_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j7dzysjU_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q8xRji3N_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qk3dR7Zh_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GWIGskY_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bGfu74pi_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x1VKrFwA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_x3CzlFuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nnrE2Mdq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Fd87xuVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xTjTuCfd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sUE0wkUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ntijDT3h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qPdd72o1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lhYvcIhd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_co6oyDeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AIX8m6E2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MgR2uAQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WeoKJBiz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_G4T8Pr9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f3UEQxSd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_j7dzysjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JcxqlajY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_q8xRji3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LcDkLK5A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qk3dR7Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wGveeuzT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3GWIGskY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ecPUV4HS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bGfu74pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ant8WjlB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_x1VKrFwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WUGdRvIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nOqSRuta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nuupajjK, HV_BINOP_MULTIPLY, 0, m, &cBinop_nuupajjK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nuupajjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iH40phNk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_x4CiY37p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8OPjnpD7, 0, m, &cVar_8OPjnpD7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ca0mIoIX, 0, m, &cVar_ca0mIoIX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_S29LtLIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nOqSRuta, HV_BINOP_DIVIDE, 1, m, &cBinop_nOqSRuta_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zoGua2g7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ca0mIoIX, 0, m, &cVar_ca0mIoIX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LRCGh5bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8OPjnpD7, 0, m, &cVar_8OPjnpD7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nnrE2Mdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xTjTuCfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ntijDT3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lhYvcIhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AIX8m6E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WeoKJBiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f3UEQxSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JcxqlajY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LcDkLK5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wGveeuzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ecPUV4HS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ant8WjlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WUGdRvIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoGua2g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LRCGh5bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_K9EqvbVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sa7LNEOs, HV_BINOP_DIVIDE, 0, m, &cBinop_Sa7LNEOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JDJFY2fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHJhPDLg, HV_BINOP_MULTIPLY, 1, m, &cBinop_RHJhPDLg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ItoAzS5g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gTuknUUv, 0, m, &cSlice_gTuknUUv_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TbCSIczO, 0, m, &cSlice_TbCSIczO_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_14cBlMkf_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TqjuiRng_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gTuknUUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_qktQjPbq, 0, m, &cVar_qktQjPbq_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_qktQjPbq, 0, m, &cVar_qktQjPbq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_TbCSIczO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lr0zROs8, HV_BINOP_NEQ, 1, m, &cBinop_lr0zROs8_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_qktQjPbq, 1, m, &cVar_qktQjPbq_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lr0zROs8, HV_BINOP_NEQ, 1, m, &cBinop_lr0zROs8_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_qktQjPbq, 1, m, &cVar_qktQjPbq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_qktQjPbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_uEZ6rFbH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_OIrhFDof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rlZod3XY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WOydsenU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_WOydsenU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qktQjPbq, 0, m, &cVar_qktQjPbq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rlZod3XY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lr0zROs8, HV_BINOP_NEQ, 1, m, &cBinop_lr0zROs8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lr0zROs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OIrhFDof, 1, m, &cIf_OIrhFDof_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TqjuiRng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OIrhFDof, 0, m, &cIf_OIrhFDof_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_14cBlMkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lr0zROs8, HV_BINOP_NEQ, 0, m, &cBinop_lr0zROs8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_6Yzmzf8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_10JBSXtR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_66E1sfEF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_U47uoRrB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s5zpohYx_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZZvCWUYI_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QIm5ZKco_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U1s2l9rF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QdT5p2sQ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Im2UmZCX_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_txifAAoT_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PpS7AnFb_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcB3CIY9_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S15ajLlg_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aaPuIC9L_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JoLWsPd4_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n36Xf8R2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_s5zpohYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mxIQO7F1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZZvCWUYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9FLiMnS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QIm5ZKco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WM0OhukT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_U1s2l9rF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mI6iN3Oo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QdT5p2sQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Obog3vrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Im2UmZCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AyoXvy8x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_txifAAoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qCN1eJWQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PpS7AnFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rhOTtvqV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YcB3CIY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I5VTFMzy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_S15ajLlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcOVf94P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aaPuIC9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rjl18qa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JoLWsPd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iqTVXYSc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_n36Xf8R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qqs9B2sP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Sa7LNEOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHJhPDLg, HV_BINOP_MULTIPLY, 0, m, &cBinop_RHJhPDLg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RHJhPDLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ItoAzS5g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_66E1sfEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K9EqvbVT, 0, m, &cVar_K9EqvbVT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JDJFY2fp, 0, m, &cVar_JDJFY2fp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_10JBSXtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sa7LNEOs, HV_BINOP_DIVIDE, 1, m, &cBinop_Sa7LNEOs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4MgeADMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JDJFY2fp, 0, m, &cVar_JDJFY2fp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qcwDquji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K9EqvbVT, 0, m, &cVar_K9EqvbVT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mxIQO7F1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9FLiMnS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WM0OhukT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mI6iN3Oo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Obog3vrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AyoXvy8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qCN1eJWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rhOTtvqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I5VTFMzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NcOVf94P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Rjl18qa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iqTVXYSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qqs9B2sP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MgeADMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcwDquji_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zxJtCvP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KpkOgGQ5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R26KDCdc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rjSTXyyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KpkOgGQ5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R26KDCdc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_P9CZWJVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KpkOgGQ5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R26KDCdc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_k1H2LDST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KpkOgGQ5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R26KDCdc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2jmUOVqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KpkOgGQ5_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R26KDCdc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZFK1Xejc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_bRDBtdpL, 0, m, &cVar_bRDBtdpL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ztBU88LG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SC554AVX, 0, m, &cVar_SC554AVX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RnxCcW47, 0, m, &cVar_RnxCcW47_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fnK7XIqC, 0, m, &cVar_fnK7XIqC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rDiI1HRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDXE2MgZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_KkD7xSWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDXE2MgZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_tR7NS6Uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wUcHYjhN, 0, m, &cVar_wUcHYjhN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bpziFsEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tK517MUO, 0, m, &cVar_tK517MUO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JHigsre1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N6x23vPK, 0, m, &cVar_N6x23vPK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZaiQz2EP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDXE2MgZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lwTLeUUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDXE2MgZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_R9cenRjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5YyZwON2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_owuJMusS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5YyZwON2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_KVpgIXue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KZs3SSrk, 0, m, &cVar_KZs3SSrk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DrqyeYUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jwo37R3o, 0, m, &cVar_Jwo37R3o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4Rm2UZIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JlY8nh9E, 0, m, &cVar_JlY8nh9E_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J1M4nSNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5YyZwON2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SDwpNta5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5YyZwON2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SkrhpYjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_TNhRL3B1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HwxicpPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_TNhRL3B1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_inHAwDdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HgH2LGcN, 0, m, &cVar_HgH2LGcN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s4vyRlkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WmUSbVJj, 0, m, &cVar_WmUSbVJj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FFknsckW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vEE1Ir0w, 0, m, &cVar_vEE1Ir0w_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0da6I5NF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_TNhRL3B1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_h51RqpoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_TNhRL3B1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_4hNNao9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fw2Nui99, 0, m, &cVar_Fw2Nui99_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YQL9Ft6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_guywWtqW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tzBnHSbe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XTAfrOS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4VpLSaKl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U4eOMDbM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4VpLSaKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CBB6tHb8, 1, m, &cIf_CBB6tHb8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U4eOMDbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eatG82sW, 0, m, &cVar_eatG82sW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tzBnHSbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fw2Nui99, 0, m, &cVar_Fw2Nui99_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_guywWtqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_02423VRz, 1, m, &cIf_02423VRz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4lrpMb4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jqw3Fv8C, 0, m, &cVar_Jqw3Fv8C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cucSzniA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dMzJfdeF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xOVAPHz3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TBZWxdBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZ43no1I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_92vcHlcx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iZ43no1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZPl7FYg3, 1, m, &cIf_ZPl7FYg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_92vcHlcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fcIUli0h, 0, m, &cVar_fcIUli0h_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xOVAPHz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jqw3Fv8C, 0, m, &cVar_Jqw3Fv8C_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dMzJfdeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AnOPITcH, 1, m, &cIf_AnOPITcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uEZ6rFbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bhi1km0g, 0, m, &cVar_bhi1km0g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_01uGa5w5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1h40c5SD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_txXIRzI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IdfJyLsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4koZIwjg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F6DmRF3T_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4koZIwjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oJgqKzrj, 1, m, &cIf_oJgqKzrj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F6DmRF3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6Iv9SVuQ, 0, m, &cVar_6Iv9SVuQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1h40c5SD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fjMAGoob, 1, m, &cIf_fjMAGoob_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_txXIRzI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bhi1km0g, 0, m, &cVar_bhi1km0g_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Y3V4f5UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SC554AVX, 0, m, &cVar_SC554AVX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Eg0TPgaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RnxCcW47, 0, m, &cVar_RnxCcW47_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_c9ZJDBcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fnK7XIqC, 0, m, &cVar_fnK7XIqC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yKRQm83L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YfmffLRQ, 0, m, &cVar_YfmffLRQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3dqZyNzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K9wVXyYN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UL35I3O5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wwgSTt6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kJcKavH2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1rXWmpkE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9Rasn9x6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_d1Zln7jT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XmeBrUeE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qysMgYVB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_86F8pIp4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wIl0hDwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4oQOQ4mD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JM4obH7q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cl45ItE4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GLA5nnEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CRcXX2hJ_sendMessage(_c, 0, m);
  cMsg_JcbDliDr_sendMessage(_c, 0, m);
  cMsg_pGCgz5SD_sendMessage(_c, 0, m);
  cMsg_sxrRrA1q_sendMessage(_c, 0, m);
  cMsg_2pEfwchv_sendMessage(_c, 0, m);
  cMsg_p8byiyKa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zAO2NJyR, 0, m, &cVar_zAO2NJyR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YfmffLRQ, 0, m, &cVar_YfmffLRQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dRnx8aOy, 0, m, &cVar_dRnx8aOy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lsICW6Ef, 0, m, &cVar_lsICW6Ef_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5X7OaLsT, 0, m, &cVar_5X7OaLsT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bor8zo2u, 0, m, &cVar_Bor8zo2u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H7ZuMtp3, 0, m, &cVar_H7ZuMtp3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AXMVPglc, 0, m, &cVar_AXMVPglc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BPDWe5hd, 0, m, &cVar_BPDWe5hd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QSA0i7qf, 0, m, &cVar_QSA0i7qf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_541IzmcS, 0, m, &cVar_541IzmcS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_I9sCI1nX, 0, m, &cVar_I9sCI1nX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sQCsvcCF, 0, m, &cVar_sQCsvcCF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m3jLGELn, 0, m, &cVar_m3jLGELn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UP364Jyl, 0, m, &cVar_UP364Jyl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qGgWQH7u, 0, m, &cVar_qGgWQH7u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fjGqHcH3, 0, m, &cVar_fjGqHcH3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AUYb7yyj, 0, m, &cVar_AUYb7yyj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Vmhoq3vm, 0, m, &cVar_Vmhoq3vm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iTjgMaCJ, 0, m, &cVar_iTjgMaCJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_owLBvaTK, 0, m, &cVar_owLBvaTK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_urrr3jAw, 0, m, &cVar_urrr3jAw_sendMessage);
  cMsg_TAkrk2FO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gRKl002F, 0, m, &cVar_gRKl002F_sendMessage);
  cMsg_v9ob1OgB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qIkhJdFo, 0, m, &cVar_qIkhJdFo_sendMessage);
  cMsg_8SQ7AJcz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xc8rPMR9, 0, m, &cVar_xc8rPMR9_sendMessage);
  cMsg_xo7leFgD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PvqehwdS, 0, m, &cVar_PvqehwdS_sendMessage);
  cMsg_DsIAAQ7h_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LF0cb9pe, 0, m, &cVar_LF0cb9pe_sendMessage);
  cMsg_dRDgOLoN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BupxHVXU, 0, m, &cVar_BupxHVXU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Tm1s5vAN, 0, m, &cVar_Tm1s5vAN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xyyOTJXW, 0, m, &cVar_xyyOTJXW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Z2CYF87, 0, m, &cVar_8Z2CYF87_sendMessage);
  cMsg_NHAtjrba_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_l4VZk7Pj, 0, m, &cVar_l4VZk7Pj_sendMessage);
  cMsg_ikxKlCjm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_o9ugZ9rR, 0, m, &cVar_o9ugZ9rR_sendMessage);
  cMsg_C5ZTJkwK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xPmnxjRP, 0, m, &cVar_xPmnxjRP_sendMessage);
  cMsg_RolXLF8Q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zXdmqJkK, 0, m, &cVar_zXdmqJkK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rI76b9rE, 0, m, &cVar_rI76b9rE_sendMessage);
  cMsg_bQ1tCbRu_sendMessage(_c, 0, m);
  cMsg_OFdU3UWD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CbfpwLXS, 0, m, &cVar_CbfpwLXS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y02uujw4, 0, m, &cVar_Y02uujw4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f72vXSLM, 0, m, &cVar_f72vXSLM_sendMessage);
  cMsg_FPfkIvd6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ciroSFWp, 0, m, &cVar_ciroSFWp_sendMessage);
  cMsg_dYAxg481_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_85MXhTsT, 0, m, &cVar_85MXhTsT_sendMessage);
  cMsg_p96WOVJb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6mKWfkcg, 0, m, &cVar_6mKWfkcg_sendMessage);
  cMsg_Q9CUzMPk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_200mAezC, 0, m, &cVar_200mAezC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GAEOp89w, 0, m, &cVar_GAEOp89w_sendMessage);
  cMsg_A6LhcTob_sendMessage(_c, 0, m);
  cMsg_qiAvcrKG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0JRyog2e, 0, m, &cVar_0JRyog2e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sf9cDpV6, 0, m, &cVar_Sf9cDpV6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_J7XYPB7d, 0, m, &cVar_J7XYPB7d_sendMessage);
  cMsg_Ls77NkA9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HyOoQTG2, 0, m, &cVar_HyOoQTG2_sendMessage);
  cMsg_0fIR0u7s_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_83Aqljyc, 0, m, &cVar_83Aqljyc_sendMessage);
  cMsg_au0ELK8A_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yqMxRPMY, 0, m, &cVar_yqMxRPMY_sendMessage);
  cMsg_SEBW9tX0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oIozDihk, 0, m, &cVar_oIozDihk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xdQtQVLE, 0, m, &cVar_xdQtQVLE_sendMessage);
  cMsg_7HhTrDMU_sendMessage(_c, 0, m);
  cMsg_nUelrcBh_sendMessage(_c, 0, m);
  cMsg_ztBU88LG_sendMessage(_c, 0, m);
  cMsg_ZFK1Xejc_sendMessage(_c, 0, m);
  cMsg_DX6QVhzJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_N0tkwQMR, 0, m, &cVar_N0tkwQMR_sendMessage);
  cMsg_KNPkIDhY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cNSuZUQ3, 0, m, &cTabhead_cNSuZUQ3_sendMessage);
  cMsg_4G0Uvefv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uJzzydHj, 0, m, &cVar_uJzzydHj_sendMessage);
  cMsg_Oma7Y3Zf_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OtwtNCH8, 0, m, &cTabhead_OtwtNCH8_sendMessage);
  cMsg_dPzNQbaa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ooHG4pu4, 0, m, &cVar_ooHG4pu4_sendMessage);
  cMsg_gcBVkdGp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IiVFJpOc, 0, m, &cTabhead_IiVFJpOc_sendMessage);
  cMsg_hZAx4uRT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xr0amzKT, 0, m, &cVar_xr0amzKT_sendMessage);
  cMsg_NhDPrTUR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ha4NXJFC, 0, m, &cTabhead_ha4NXJFC_sendMessage);
  cMsg_URmEsHLm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iMMUUyyV, 0, m, &cVar_iMMUUyyV_sendMessage);
  cMsg_b59igsKi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kfkfjS5G, 0, m, &cTabhead_kfkfjS5G_sendMessage);
  cMsg_sQrVjwsq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CttQjvSn, 0, m, &cVar_CttQjvSn_sendMessage);
  cMsg_Q26rKc62_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_IMZ4GTPp, 0, m, &cTabhead_IMZ4GTPp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_f6P0fv8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rnh85uyo, HV_BINOP_MULTIPLY, 0, m, &cBinop_rnh85uyo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_a8dGpp3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_43Zo6DQb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oUZT6j3x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JRgyMGZS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0R4Pbetq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZfQgwXm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CPSRCz7Q_sendMessage);
  cMsg_bLN3Jutr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_MGwZhSzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxpROE4D, HV_BINOP_MULTIPLY, 0, m, &cBinop_bxpROE4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HSrLVAWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3SAOsZ1Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_83WpDu5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZds6qLQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_UZds6qLQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SIP994M6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_T6ANuB8p_sendMessage);
  cMsg_9mdVk3oH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_GNHq3hlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cxZYBH5W, HV_BINOP_MULTIPLY, 0, m, &cBinop_cxZYBH5W_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gim0s1Ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pNauEZ7t_sendMessage(_c, 0, m);
  cMsg_NFx5XSda_sendMessage(_c, 0, m);
  cMsg_xdw3ND6T_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TLny2OUh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Dw3Njss2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GjpduVuv_sendMessage);
  cMsg_lX32cwk1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_sk0KdA17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5X7OaLsT, 0, m, &cVar_5X7OaLsT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_o5hkpmXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q9wXp1K4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JNHWjv4C_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vP35XqAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rJV7vtTa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rjNcSWZU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eDNG5AUa_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zrBmv9We_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KKFF1iRU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xuh3OQ9Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w8sHjuN8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9hZYS9AS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iTTGh138_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L6O2nhht_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tpUKG4Sn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WbM8mQ8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7xauLtuF, HV_BINOP_MULTIPLY, 0, m, &cBinop_7xauLtuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vxs2tsSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rJXiGHAE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_j8bj0vki_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uZaq1K5k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5DXiaoBO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MK1tHD6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xvATCA32_sendMessage);
  cMsg_i9ThNRnq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_sF5pUPnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JIIfIUMj, HV_BINOP_MULTIPLY, 0, m, &cBinop_JIIfIUMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uAI1rzWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Tf5siKUO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BvEpP4OH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wXezlk8R, HV_BINOP_MULTIPLY, 1, m, &cBinop_wXezlk8R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gKSUXs6p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gDazW3us_sendMessage);
  cMsg_gaCN01ay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_MZnbM4zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSZ7QY7q, HV_BINOP_MULTIPLY, 0, m, &cBinop_gSZ7QY7q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4mbzMfq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e1sToFxu_sendMessage(_c, 0, m);
  cMsg_uSGSnH3T_sendMessage(_c, 0, m);
  cMsg_kRTHF5tC_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_CowEW4Zg_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Kg1W4zpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CRUrVkcY_sendMessage);
  cMsg_Y4x9zrIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_ATcPJ9v4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bRDBtdpL, 0, m, &cVar_bRDBtdpL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iISwT6hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_tR7NS6Uw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hN56lwLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bpziFsEi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qfuJO66B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_JHigsre1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_a4q4uLgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_KVpgIXue_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dLzcI2Sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DrqyeYUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_S2bOh4s0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_inHAwDdw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_K8VM2pvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_s4vyRlkj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_JxeXTe9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FFknsckW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AmybYhAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_4Rm2UZIA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XQlQgDH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5VubsKcw, HV_BINOP_MULTIPLY, 1, m, &cBinop_5VubsKcw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oK4JAGnv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YJfUIxIy, HV_BINOP_MULTIPLY, 1, m, &cBinop_YJfUIxIy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_soZXrRlM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AknuaiHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_daCreM4f, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SYRDSIpl, m);
}

void Heavy_WSTD_DL3Y::cReceive_7VCpA57F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YE9egiLX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kK3yICrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yzTZJeKh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1ZkOiKJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pE4K1zTa, HV_BINOP_MULTIPLY, 1, m, &cBinop_pE4K1zTa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hfVpMFXh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHSmIMwS, HV_BINOP_MULTIPLY, 1, m, &cBinop_bHSmIMwS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JWnSskJo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Qi5ka4dG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_avJmLMxX, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qNmzh4Bm, m);
}

void Heavy_WSTD_DL3Y::cReceive_mJEBV4pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hpkr1TlS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ahN7HzQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nqYFK04g_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zyja7CDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h0Op2nec, HV_BINOP_MULTIPLY, 1, m, &cBinop_h0Op2nec_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zMLS7Eku_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VhCdQTQM, HV_BINOP_MULTIPLY, 1, m, &cBinop_VhCdQTQM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QD0JWKjM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_71f3sNBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fkkULfn8, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_d0OuCppX, m);
}

void Heavy_WSTD_DL3Y::cReceive_QIaTxKyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Xmgrmi5d_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wPqtdMjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QYiFzmZO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UCZ6JhIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eatG82sW, 0, m, &cVar_eatG82sW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ovy3Yxn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Shlzu8rs, 0, m, &cVar_Shlzu8rs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aLiEduHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W9JWYsQr, 0, m, &cVar_W9JWYsQr_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hwWLwcB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fcIUli0h, 0, m, &cVar_fcIUli0h_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aUHNEsNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6Iv9SVuQ, 0, m, &cVar_6Iv9SVuQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_s8TLXM40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e44EFCpz, 0, m, &cVar_e44EFCpz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RhvwIogT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wtg2SQfx, 0, m, &cVar_Wtg2SQfx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rcXfBBx8, 0, m, &cVar_rcXfBBx8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6Yzmzf8D, 0, m, &cVar_6Yzmzf8D_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9qsab6jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9sqPQl8B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_74C6oiWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LvEEBHel_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_nyiVPmoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_U47uoRrB_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_6NSQsth5, VOf(Bf0));
    __hv_line_f(&sLine_Owg2YtKz, VOf(Bf1));
    __hv_line_f(&sLine_CrisXiUv, VOf(Bf2));
    __hv_line_f(&sLine_RwU0CIMw, VOf(Bf3));
    __hv_line_f(&sLine_NKOtsfnR, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_6S0tWAmx, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_jS5QTFbf, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_FVJBk0wk, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_rhOeetHW, VOf(Bf1));
    __hv_line_f(&sLine_tMhboijr, VOf(Bf0));
    __hv_line_f(&sLine_Wnf6PQ95, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_8t5ybtyo, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_K0NY6jWp, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_uiccnkjz, VOf(Bf5));
    __hv_line_f(&sLine_rEfFKhb3, VOf(Bf1));
    __hv_line_f(&sLine_CR715b1u, VOf(Bf2));
    __hv_line_f(&sLine_7AsExIOX, VOf(Bf4));
    __hv_line_f(&sLine_dDmxEGbs, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_tepSYcim, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_9r1mZhI3, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_1wsZQByj, VOf(Bf6));
    __hv_line_f(&sLine_il55jxCz, VOf(Bf2));
    __hv_line_f(&sLine_814at4iS, VOf(Bf1));
    __hv_line_f(&sLine_DhO695Aq, VOf(Bf5));
    __hv_line_f(&sLine_7hO7PyUW, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_dcUmkjUj, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_Z9hG7now, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_e0ohxC5o, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_g1Ojihd3, VOf(Bf2));
    __hv_line_f(&sLine_sEv5FaSF, VOf(Bf6));
    __hv_line_f(&sLine_lv5LIyAk, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_7mqyWKQA, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_BUwGMNzP, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_MWHRS08p, VOf(Bf8));
    __hv_line_f(&sLine_V3YKR3P2, VOf(Bf2));
    __hv_line_f(&sLine_35wh2VeU, VOf(Bf1));
    __hv_line_f(&sLine_FygbfStq, VOf(Bf7));
    __hv_line_f(&sLine_vaugzlV4, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_r8aCAKM1, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_2Yis95YL, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_Rc23rZ59, VOf(Bf9));
    __hv_tabread_f(&sTabread_WPcLVBhM, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_sYD2Uyey, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_3rxDs3xy, VOf(Bf9));
    __hv_tabread_f(&sTabread_1brIOGkA, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_Q3oZm1lY, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_EAQeZJZy, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FckXArST, VOf(Bf3));
    __hv_rpole_f(&sRPole_m7SmKRVT, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_btW8hw9K, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Dj0dNoF8, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_CYTQE1B0, VIf(Bf3));
    __hv_varread_f(&sVarf_gEBKNC8v, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_bb4GFQUg, VOf(Bf5));
    __hv_rpole_f(&sRPole_4J1uzIXJ, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_eCKLqkvs, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_eCiVjmuq, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_rrxit976, VIf(Bf5));
    __hv_varread_f(&sVarf_daCreM4f, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_4T3rMgH9, VOf(Bf1));
    __hv_varread_f(&sVarf_SYRDSIpl, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_X6SomIef, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_UAkGPCfn, VOf(Bf1));
    __hv_varread_f(&sVarf_7mHlP2Ya, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_rhe2eoJH, VOf(Bf1));
    __hv_rpole_f(&sRPole_27iG6HUy, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_oPREYVrW, VIf(Bf8), &sEnv_oPREYVrW_sendMessage);
    __hv_varread_f(&sVarf_ax01LzD8, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_cPtZosMS, VOf(Bf1));
    __hv_rpole_f(&sRPole_LcHz0YQf, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_EAQeZJZy, VIf(Bf1));
    __hv_line_f(&sLine_vrvoMgsf, VOf(Bf1));
    __hv_line_f(&sLine_eoUFaBLt, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_98VINtJS, VOf(Bf1));
    __hv_varread_f(&sVarf_MzY4EkUR, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_TJN5nFZ1, VOf(Bf1));
    __hv_rpole_f(&sRPole_EuJw5HbI, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_LhHr4qYi, VIf(Bf8), &sEnv_LhHr4qYi_sendMessage);
    __hv_varread_f(&sVarf_eJaDQ4kW, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_JqN53mXS, VOf(Bf1));
    __hv_rpole_f(&sRPole_S5y6GHOC, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_gEBKNC8v, VIf(Bf1));
    __hv_varwrite_f(&sVarf_BrRiUQCK, VIf(Bf2));
    __hv_varread_f(&sVarf_T3U5iiYe, VOf(Bf2));
    __hv_varread_f(&sVarf_olvbRCvs, VOf(Bf1));
    __hv_line_f(&sLine_451ToWYh, VOf(Bf8));
    __hv_tabread_f(&sTabread_YhFKF7eX, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_GZcbPNo3, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_GH1DHAYX, VOf(Bf8));
    __hv_tabread_f(&sTabread_yYfm8epR, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_vAkhrvc9, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_Vh32kgeY, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_WUr6BnDG, VOf(Bf2));
    __hv_rpole_f(&sRPole_VJE2VYNO, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_KkcPph27, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_z33QE8Q7, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_X1aicy1o, VIf(Bf2));
    __hv_varread_f(&sVarf_s8yq2HGa, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_nNTUL8PY, VOf(Bf1));
    __hv_rpole_f(&sRPole_OKQ1W2eq, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_UALfFmfW, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_FG2fuiGx, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_hpQ3UYZp, VIf(Bf1));
    __hv_varread_f(&sVarf_avJmLMxX, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_IVwkv12O, VOf(Bf3));
    __hv_varread_f(&sVarf_qNmzh4Bm, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_fAiGLOpp, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_IziHBJrK, VOf(Bf3));
    __hv_varread_f(&sVarf_opO13Pww, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HQghlH9Y, VOf(Bf3));
    __hv_rpole_f(&sRPole_Z1C7oCjU, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_nE6lbdBw, VIf(Bf9), &sEnv_nE6lbdBw_sendMessage);
    __hv_varread_f(&sVarf_YQdUPxPp, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_wNHqX7AG, VOf(Bf3));
    __hv_rpole_f(&sRPole_vEyEF2HB, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_Vh32kgeY, VIf(Bf3));
    __hv_line_f(&sLine_jM0z6W93, VOf(Bf3));
    __hv_line_f(&sLine_nkGOeCMc, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_e8WCIrK3, VOf(Bf3));
    __hv_varread_f(&sVarf_P5qE9dVf, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_eN0RH2FW, VOf(Bf3));
    __hv_rpole_f(&sRPole_8Vw9vUUy, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_7QKfknxM, VIf(Bf9), &sEnv_7QKfknxM_sendMessage);
    __hv_varread_f(&sVarf_7SlQm7NT, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Ln00Kr2x, VOf(Bf3));
    __hv_rpole_f(&sRPole_dGiyTGlx, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_s8yq2HGa, VIf(Bf3));
    __hv_varwrite_f(&sVarf_01eZnNo3, VIf(Bf5));
    __hv_varread_f(&sVarf_S5p8NP6v, VOf(Bf5));
    __hv_varread_f(&sVarf_4rPOSZxG, VOf(Bf3));
    __hv_line_f(&sLine_Kq0aZiNG, VOf(Bf9));
    __hv_tabread_f(&sTabread_E62LNqw6, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_hglLjnnF, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_FnvMwhTf, VOf(Bf9));
    __hv_tabread_f(&sTabread_pj97Vfhv, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_hvgOBvy7, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_XfjXisw4, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_dh5GWp7q, VOf(Bf5));
    __hv_rpole_f(&sRPole_n614MNPC, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_kwFla7Au, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_lZJ2qzKt, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_xoc7icvo, VIf(Bf5));
    __hv_varread_f(&sVarf_DzIoH3I9, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_X4fN5Y2L, VOf(Bf3));
    __hv_rpole_f(&sRPole_TIuOO6wo, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_wFXJeUTQ, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_W4fyXXpU, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_SanbvW7K, VIf(Bf3));
    __hv_varread_f(&sVarf_fkkULfn8, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_POOmXL08, VOf(Bf2));
    __hv_varread_f(&sVarf_d0OuCppX, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_2D69JTTP, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_rIHauaqU, VOf(Bf2));
    __hv_varread_f(&sVarf_BftbGXW0, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_HnTmPoHQ, VOf(Bf2));
    __hv_rpole_f(&sRPole_SGpvxC45, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_8NFZ0dcN, VIf(Bf8), &sEnv_8NFZ0dcN_sendMessage);
    __hv_varread_f(&sVarf_nrESerZN, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_S3OKdy2M, VOf(Bf2));
    __hv_rpole_f(&sRPole_ZTRMYumW, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_XfjXisw4, VIf(Bf2));
    __hv_line_f(&sLine_CM1mrbNv, VOf(Bf2));
    __hv_line_f(&sLine_9HSftv9E, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_C9mlg7bP, VOf(Bf2));
    __hv_varread_f(&sVarf_GYe8vt10, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_5zY9b8d7, VOf(Bf2));
    __hv_rpole_f(&sRPole_GUhy2XkS, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_zq3ROpKc, VIf(Bf8), &sEnv_zq3ROpKc_sendMessage);
    __hv_varread_f(&sVarf_pMFSKvRq, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ypNloANd, VOf(Bf2));
    __hv_rpole_f(&sRPole_7gx86sl6, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_DzIoH3I9, VIf(Bf2));
    __hv_varwrite_f(&sVarf_hdNWxOjP, VIf(Bf1));
    __hv_varwrite_f(&sVarf_7aHLPc0M, VIf(Bf10));
    __hv_varwrite_f(&sVarf_wsOSckws, VIf(Bf11));
    __hv_varwrite_f(&sVarf_3qrdQB7U, VIf(Bf12));
    __hv_varwrite_f(&sVarf_T3U5iiYe, VIf(Bf0));
    __hv_varwrite_f(&sVarf_olvbRCvs, VIf(Bf6));
    __hv_varwrite_f(&sVarf_S5p8NP6v, VIf(Bf4));
    __hv_varwrite_f(&sVarf_4rPOSZxG, VIf(Bf7));
    __hv_varread_f(&sVarf_7aHLPc0M, VOf(Bf7));
    __hv_varread_f(&sVarf_wsOSckws, VOf(Bf4));
    __hv_varread_f(&sVarf_3qrdQB7U, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_BrRiUQCK, VOf(Bf6));
    __hv_varread_f(&sVarf_01eZnNo3, VOf(Bf7));
    __hv_varread_f(&sVarf_hdNWxOjP, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
